Class: ApiReference::AccountingProvider

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/accounting_provider.rb

Overview

AccountingProvider Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(provider_type:, external_provider_id:, additional_properties: nil) ⇒ AccountingProvider

Returns a new instance of AccountingProvider.



40
41
42
43
44
45
46
47
48
# File 'lib/api_reference/models/accounting_provider.rb', line 40

def initialize(provider_type:, external_provider_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @provider_type = provider_type
  @external_provider_id = external_provider_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#external_provider_idString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/api_reference/models/accounting_provider.rb', line 18

def external_provider_id
  @external_provider_id
end

#provider_typeProviderType

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/api_reference/models/accounting_provider.rb', line 14

def provider_type
  @provider_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/api_reference/models/accounting_provider.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  provider_type = hash.key?('provider_type') ? hash['provider_type'] : nil
  external_provider_id =
    hash.key?('external_provider_id') ? hash['external_provider_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountingProvider.new(provider_type: provider_type,
                         external_provider_id: external_provider_id,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/accounting_provider.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['provider_type'] = 'provider_type'
  @_hash['external_provider_id'] = 'external_provider_id'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
37
38
# File 'lib/api_reference/models/accounting_provider.rb', line 34

def self.nullables
  %w[
    external_provider_id
  ]
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/api_reference/models/accounting_provider.rb', line 29

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/api_reference/models/accounting_provider.rb', line 74

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.provider_type,
                            ->(val) { ProviderType.validate(val) }) and
        APIHelper.valid_type?(value.external_provider_id,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['provider_type'],
                          ->(val) { ProviderType.validate(val) }) and
      APIHelper.valid_type?(value['external_provider_id'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
# File 'lib/api_reference/models/accounting_provider.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} provider_type: #{@provider_type.inspect}, external_provider_id:"\
  " #{@external_provider_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
# File 'lib/api_reference/models/accounting_provider.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} provider_type: #{@provider_type}, external_provider_id:"\
  " #{@external_provider_id}, additional_properties: #{@additional_properties}>"
end