Class: ApiReference::AddPlanAdjustmentParams

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/add_plan_adjustment_params.rb

Overview

AddPlanAdjustmentParams Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(adjustment:, plan_phase_order: SKIP) ⇒ AddPlanAdjustmentParams

Returns a new instance of AddPlanAdjustmentParams.



42
43
44
45
# File 'lib/api_reference/models/add_plan_adjustment_params.rb', line 42

def initialize(adjustment:, plan_phase_order: SKIP)
  @adjustment = adjustment
  @plan_phase_order = plan_phase_order unless plan_phase_order == SKIP
end

Instance Attribute Details

#adjustmentObject

The definition of a new adjustment to create and add to the plan.

Returns:

  • (Object)


14
15
16
# File 'lib/api_reference/models/add_plan_adjustment_params.rb', line 14

def adjustment
  @adjustment
end

#plan_phase_orderInteger

The phase to add this adjustment to.

Returns:

  • (Integer)


18
19
20
# File 'lib/api_reference/models/add_plan_adjustment_params.rb', line 18

def plan_phase_order
  @plan_phase_order
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/api_reference/models/add_plan_adjustment_params.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  adjustment = hash.key?('adjustment') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:AddPlanAdjustmentParamsAdjustment), hash['adjustment']
  ) : nil
  plan_phase_order =
    hash.key?('plan_phase_order') ? hash['plan_phase_order'] : SKIP

  # Create object from extracted values.
  AddPlanAdjustmentParams.new(adjustment: adjustment,
                              plan_phase_order: plan_phase_order)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/add_plan_adjustment_params.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['adjustment'] = 'adjustment'
  @_hash['plan_phase_order'] = 'plan_phase_order'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
39
40
# File 'lib/api_reference/models/add_plan_adjustment_params.rb', line 36

def self.nullables
  %w[
    plan_phase_order
  ]
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/api_reference/models/add_plan_adjustment_params.rb', line 29

def self.optionals
  %w[
    plan_phase_order
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



65
66
67
68
69
70
71
72
73
74
75
# File 'lib/api_reference/models/add_plan_adjustment_params.rb', line 65

def self.validate(value)
  if value.instance_of? self
    return UnionTypeLookUp.get(:AddPlanAdjustmentParamsAdjustment)
                          .validate(value.adjustment)
  end

  return false unless value.instance_of? Hash

  UnionTypeLookUp.get(:AddPlanAdjustmentParamsAdjustment)
                 .validate(value['adjustment'])
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/api_reference/models/add_plan_adjustment_params.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} adjustment: #{@adjustment.inspect}, plan_phase_order:"\
  " #{@plan_phase_order.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
# File 'lib/api_reference/models/add_plan_adjustment_params.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} adjustment: #{@adjustment}, plan_phase_order: #{@plan_phase_order}>"
end