Class: ApiReference::AmountDiscountCreationParams

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/amount_discount_creation_params.rb

Overview

AmountDiscountCreationParams Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount_discount:, additional_properties: nil) ⇒ AmountDiscountCreationParams

Returns a new instance of AmountDiscountCreationParams.



38
39
40
41
42
43
44
45
# File 'lib/api_reference/models/amount_discount_creation_params.rb', line 38

def initialize(amount_discount:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @discount_type = 'amount'
  @amount_discount = amount_discount
  @additional_properties = additional_properties
end

Instance Attribute Details

#amount_discountFloat

Only available if discount_type is amount.

Returns:

  • (Float)


18
19
20
# File 'lib/api_reference/models/amount_discount_creation_params.rb', line 18

def amount_discount
  @amount_discount
end

#discount_typeString (readonly)

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/amount_discount_creation_params.rb', line 14

def discount_type
  @discount_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/api_reference/models/amount_discount_creation_params.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount_discount =
    hash.key?('amount_discount') ? hash['amount_discount'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AmountDiscountCreationParams.new(amount_discount: amount_discount,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/amount_discount_creation_params.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['discount_type'] = 'discount_type'
  @_hash['amount_discount'] = 'amount_discount'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/api_reference/models/amount_discount_creation_params.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/api_reference/models/amount_discount_creation_params.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
79
# File 'lib/api_reference/models/amount_discount_creation_params.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} discount_type: #{@discount_type.inspect}, amount_discount:"\
  " #{@amount_discount.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



68
69
70
71
72
# File 'lib/api_reference/models/amount_discount_creation_params.rb', line 68

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} discount_type: #{@discount_type}, amount_discount: #{@amount_discount},"\
  " additional_properties: #{@additional_properties}>"
end