Class: ApiReference::BlockPriceFilter

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/block_price_filter.rb

Overview

A PriceFilter that only allows item_id field for block filters.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(operator:, values:, additional_properties: nil) ⇒ BlockPriceFilter

Returns a new instance of BlockPriceFilter.



43
44
45
46
47
48
49
50
51
# File 'lib/api_reference/models/block_price_filter.rb', line 43

def initialize(operator:, values:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @field = 'item_id'
  @operator = operator
  @values = values
  @additional_properties = additional_properties
end

Instance Attribute Details

#fieldString (readonly)

The property of the price the block applies to. Only item_id is supported.

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/block_price_filter.rb', line 14

def field
  @field
end

#operatorOperator

Should prices that match the filter be included or excluded.

Returns:



18
19
20
# File 'lib/api_reference/models/block_price_filter.rb', line 18

def operator
  @operator
end

#valuesArray[String]

The IDs or values that match this filter.

Returns:

  • (Array[String])


22
23
24
# File 'lib/api_reference/models/block_price_filter.rb', line 22

def values
  @values
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/api_reference/models/block_price_filter.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  operator = hash.key?('operator') ? hash['operator'] : nil
  values = hash.key?('values') ? hash['values'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BlockPriceFilter.new(operator: operator,
                       values: values,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/api_reference/models/block_price_filter.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['field'] = 'field'
  @_hash['operator'] = 'operator'
  @_hash['values'] = 'values'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/api_reference/models/block_price_filter.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/api_reference/models/block_price_filter.rb', line 34

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/api_reference/models/block_price_filter.rb', line 76

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.field,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.operator,
                              ->(val) { Operator.validate(val) }) and
        APIHelper.valid_type?(value.values,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['field'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['operator'],
                            ->(val) { Operator.validate(val) }) and
      APIHelper.valid_type?(value['values'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
# File 'lib/api_reference/models/block_price_filter.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} field: #{@field.inspect}, operator: #{@operator.inspect}, values:"\
  " #{@values.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
# File 'lib/api_reference/models/block_price_filter.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} field: #{@field}, operator: #{@operator}, values: #{@values},"\
  " additional_properties: #{@additional_properties}>"
end