Class: ApiReference::BulkWithProrationConfig1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::BulkWithProrationConfig1
- Defined in:
- lib/api_reference/models/bulk_with_proration_config1.rb
Overview
Configuration for bulk_with_proration pricing
Instance Attribute Summary collapse
-
#tiers ⇒ Array[BulkTierWithProration]
Bulk tiers for rating based on total usage volume.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(tiers:) ⇒ BulkWithProrationConfig1
constructor
A new instance of BulkWithProrationConfig1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tiers:) ⇒ BulkWithProrationConfig1
Returns a new instance of BulkWithProrationConfig1.
33 34 35 |
# File 'lib/api_reference/models/bulk_with_proration_config1.rb', line 33 def initialize(tiers:) @tiers = tiers end |
Instance Attribute Details
#tiers ⇒ Array[BulkTierWithProration]
Bulk tiers for rating based on total usage volume
14 15 16 |
# File 'lib/api_reference/models/bulk_with_proration_config1.rb', line 14 def tiers @tiers end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/api_reference/models/bulk_with_proration_config1.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it tiers = nil unless hash['tiers'].nil? tiers = [] hash['tiers'].each do |structure| tiers << (BulkTierWithProration.from_hash(structure) if structure) end end tiers = nil unless hash.key?('tiers') # Create object from extracted values. BulkWithProrationConfig1.new(tiers: tiers) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/api_reference/models/bulk_with_proration_config1.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['tiers'] = 'tiers' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/api_reference/models/bulk_with_proration_config1.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/api_reference/models/bulk_with_proration_config1.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/api_reference/models/bulk_with_proration_config1.rb', line 59 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.tiers, ->(val) { BulkTierWithProration.validate(val) }, is_model_hash: true, is_inner_model_hash: true) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['tiers'], ->(val) { BulkTierWithProration.validate(val) }, is_model_hash: true, is_inner_model_hash: true) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 |
# File 'lib/api_reference/models/bulk_with_proration_config1.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} tiers: #{@tiers.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 |
# File 'lib/api_reference/models/bulk_with_proration_config1.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} tiers: #{@tiers}>" end |