Class: ApiReference::ConstraintViolationError

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/constraint_violation_error.rb

Overview

ConstraintViolationError Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(detail: SKIP, title: SKIP, additional_properties: nil) ⇒ ConstraintViolationError

Returns a new instance of ConstraintViolationError.



54
55
56
57
58
59
60
61
62
63
# File 'lib/api_reference/models/constraint_violation_error.rb', line 54

def initialize(detail: SKIP, title: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = 'https://docs.withorb.com/reference/error-responses#400-constraint-violation'
  @status = 400
  @detail = detail unless detail == SKIP
  @title = title unless title == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#detailString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/api_reference/models/constraint_violation_error.rb', line 22

def detail
  @detail
end

#statusInteger (readonly)

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/api_reference/models/constraint_violation_error.rb', line 18

def status
  @status
end

#titleString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/api_reference/models/constraint_violation_error.rb', line 26

def title
  @title
end

#typeString (readonly)

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/constraint_violation_error.rb', line 14

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/api_reference/models/constraint_violation_error.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  detail = hash.key?('detail') ? hash['detail'] : SKIP
  title = hash.key?('title') ? hash['title'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ConstraintViolationError.new(detail: detail,
                               title: title,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/api_reference/models/constraint_violation_error.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['status'] = 'status'
  @_hash['detail'] = 'detail'
  @_hash['title'] = 'title'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
50
51
52
# File 'lib/api_reference/models/constraint_violation_error.rb', line 47

def self.nullables
  %w[
    detail
    title
  ]
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
# File 'lib/api_reference/models/constraint_violation_error.rb', line 39

def self.optionals
  %w[
    detail
    title
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
99
# File 'lib/api_reference/models/constraint_violation_error.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, status: #{@status.inspect}, detail:"\
  " #{@detail.inspect}, title: #{@title.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
# File 'lib/api_reference/models/constraint_violation_error.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, status: #{@status}, detail: #{@detail}, title: #{@title},"\
  " additional_properties: #{@additional_properties}>"
end