Class: ApiReference::ConversionRateTier
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::ConversionRateTier
- Defined in:
- lib/api_reference/models/conversion_rate_tier.rb
Overview
ConversionRateTier Model.
Instance Attribute Summary collapse
-
#first_unit ⇒ Float
Exclusive tier starting value.
-
#last_unit ⇒ Float
Inclusive tier ending value.
-
#unit_amount ⇒ String
Amount per unit of overage.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(first_unit:, unit_amount:, last_unit: SKIP) ⇒ ConversionRateTier
constructor
A new instance of ConversionRateTier.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(first_unit:, unit_amount:, last_unit: SKIP) ⇒ ConversionRateTier
Returns a new instance of ConversionRateTier.
47 48 49 50 51 |
# File 'lib/api_reference/models/conversion_rate_tier.rb', line 47 def initialize(first_unit:, unit_amount:, last_unit: SKIP) @first_unit = first_unit @last_unit = last_unit unless last_unit == SKIP @unit_amount = unit_amount end |
Instance Attribute Details
#first_unit ⇒ Float
Exclusive tier starting value
14 15 16 |
# File 'lib/api_reference/models/conversion_rate_tier.rb', line 14 def first_unit @first_unit end |
#last_unit ⇒ Float
Inclusive tier ending value. If null, this is treated as the last tier
18 19 20 |
# File 'lib/api_reference/models/conversion_rate_tier.rb', line 18 def last_unit @last_unit end |
#unit_amount ⇒ String
Amount per unit of overage
22 23 24 |
# File 'lib/api_reference/models/conversion_rate_tier.rb', line 22 def unit_amount @unit_amount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/api_reference/models/conversion_rate_tier.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. first_unit = hash.key?('first_unit') ? hash['first_unit'] : nil unit_amount = hash.key?('unit_amount') ? hash['unit_amount'] : nil last_unit = hash.key?('last_unit') ? hash['last_unit'] : SKIP # Create object from extracted values. ConversionRateTier.new(first_unit: first_unit, unit_amount: unit_amount, last_unit: last_unit) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/api_reference/models/conversion_rate_tier.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['first_unit'] = 'first_unit' @_hash['last_unit'] = 'last_unit' @_hash['unit_amount'] = 'unit_amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 44 45 |
# File 'lib/api_reference/models/conversion_rate_tier.rb', line 41 def self.nullables %w[ last_unit ] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/api_reference/models/conversion_rate_tier.rb', line 34 def self.optionals %w[ last_unit ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/api_reference/models/conversion_rate_tier.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} first_unit: #{@first_unit.inspect}, last_unit: #{@last_unit.inspect},"\ " unit_amount: #{@unit_amount.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/api_reference/models/conversion_rate_tier.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} first_unit: #{@first_unit}, last_unit: #{@last_unit}, unit_amount:"\ " #{@unit_amount}>" end |