Class: ApiReference::CreditLedgerEntries
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::CreditLedgerEntries
- Defined in:
- lib/api_reference/models/credit_ledger_entries.rb
Overview
CreditLedgerEntries Model.
Instance Attribute Summary collapse
-
#data ⇒ Array[Object]
TODO: Write general description for this method.
-
#pagination_metadata ⇒ PaginationMetadata
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(data:, pagination_metadata:, additional_properties: nil) ⇒ CreditLedgerEntries
constructor
A new instance of CreditLedgerEntries.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(data:, pagination_metadata:, additional_properties: nil) ⇒ CreditLedgerEntries
Returns a new instance of CreditLedgerEntries.
38 39 40 41 42 43 44 45 |
# File 'lib/api_reference/models/credit_ledger_entries.rb', line 38 def initialize(data:, pagination_metadata:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @data = data @pagination_metadata = @additional_properties = additional_properties end |
Instance Attribute Details
#data ⇒ Array[Object]
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/credit_ledger_entries.rb', line 14 def data @data end |
#pagination_metadata ⇒ PaginationMetadata
TODO: Write general description for this method
18 19 20 |
# File 'lib/api_reference/models/credit_ledger_entries.rb', line 18 def @pagination_metadata end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/api_reference/models/credit_ledger_entries.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. data = hash.key?('data') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:CreditLedgerEntry2), hash['data'] ) : nil = PaginationMetadata.from_hash(hash['pagination_metadata']) if hash['pagination_metadata'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditLedgerEntries.new(data: data, pagination_metadata: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/api_reference/models/credit_ledger_entries.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['data'] = 'data' @_hash['pagination_metadata'] = 'pagination_metadata' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/api_reference/models/credit_ledger_entries.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/api_reference/models/credit_ledger_entries.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/api_reference/models/credit_ledger_entries.rb', line 73 def self.validate(value) if value.instance_of? self return ( UnionTypeLookUp.get(:CreditLedgerEntry2) .validate(value.data) and APIHelper.valid_type?(value., ->(val) { PaginationMetadata.validate(val) }, is_model_hash: true) ) end return false unless value.instance_of? Hash ( UnionTypeLookUp.get(:CreditLedgerEntry2) .validate(value['data']) and APIHelper.valid_type?(value['pagination_metadata'], ->(val) { PaginationMetadata.validate(val) }, is_model_hash: true) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 |
# File 'lib/api_reference/models/credit_ledger_entries.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} data: #{@data.inspect}, pagination_metadata:"\ " #{@pagination_metadata.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 |
# File 'lib/api_reference/models/credit_ledger_entries.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} data: #{@data}, pagination_metadata: #{@pagination_metadata},"\ " additional_properties: #{@additional_properties}>" end |