Class: ApiReference::CumulativeGroupedBulkConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/cumulative_grouped_bulk_config.rb

Overview

Configuration for cumulative grouped bulk pricing

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(group:, dimension_values:) ⇒ CumulativeGroupedBulkConfig

Returns a new instance of CumulativeGroupedBulkConfig.



38
39
40
41
# File 'lib/api_reference/models/cumulative_grouped_bulk_config.rb', line 38

def initialize(group:, dimension_values:)
  @group = group
  @dimension_values = dimension_values
end

Instance Attribute Details

#dimension_valuesArray[CumulativeGroupedBulkDimensionValue]

Each tier lower bound must have the same group of values.



18
19
20
# File 'lib/api_reference/models/cumulative_grouped_bulk_config.rb', line 18

def dimension_values
  @dimension_values
end

#groupString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/cumulative_grouped_bulk_config.rb', line 14

def group
  @group
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/api_reference/models/cumulative_grouped_bulk_config.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  group = hash.key?('group') ? hash['group'] : nil
  # Parameter is an array, so we need to iterate through it
  dimension_values = nil
  unless hash['dimension_values'].nil?
    dimension_values = []
    hash['dimension_values'].each do |structure|
      dimension_values << (CumulativeGroupedBulkDimensionValue.from_hash(structure) if structure)
    end
  end

  dimension_values = nil unless hash.key?('dimension_values')

  # Create object from extracted values.
  CumulativeGroupedBulkConfig.new(group: group,
                                  dimension_values: dimension_values)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/cumulative_grouped_bulk_config.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['group'] = 'group'
  @_hash['dimension_values'] = 'dimension_values'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/api_reference/models/cumulative_grouped_bulk_config.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/api_reference/models/cumulative_grouped_bulk_config.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
# File 'lib/api_reference/models/cumulative_grouped_bulk_config.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} group: #{@group.inspect}, dimension_values: #{@dimension_values.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



66
67
68
69
# File 'lib/api_reference/models/cumulative_grouped_bulk_config.rb', line 66

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} group: #{@group}, dimension_values: #{@dimension_values}>"
end