Class: ApiReference::CumulativeGroupedBulkDimensionValue

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb

Overview

Configuration for a dimension value entry

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tier_lower_bound:, grouping_key:, unit_amount:) ⇒ CumulativeGroupedBulkDimensionValue

Returns a new instance of CumulativeGroupedBulkDimensionValue.



43
44
45
46
47
# File 'lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb', line 43

def initialize(tier_lower_bound:, grouping_key:, unit_amount:)
  @tier_lower_bound = tier_lower_bound
  @grouping_key = grouping_key
  @unit_amount = unit_amount
end

Instance Attribute Details

#grouping_keyString

Grouping key value

Returns:

  • (String)


18
19
20
# File 'lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb', line 18

def grouping_key
  @grouping_key
end

#tier_lower_boundString

Tier lower bound

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb', line 14

def tier_lower_bound
  @tier_lower_bound
end

#unit_amountString

Unit amount for this combination

Returns:

  • (String)


22
23
24
# File 'lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb', line 22

def unit_amount
  @unit_amount
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tier_lower_bound =
    hash.key?('tier_lower_bound') ? hash['tier_lower_bound'] : nil
  grouping_key = hash.key?('grouping_key') ? hash['grouping_key'] : nil
  unit_amount = hash.key?('unit_amount') ? hash['unit_amount'] : nil

  # Create object from extracted values.
  CumulativeGroupedBulkDimensionValue.new(tier_lower_bound: tier_lower_bound,
                                          grouping_key: grouping_key,
                                          unit_amount: unit_amount)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tier_lower_bound'] = 'tier_lower_bound'
  @_hash['grouping_key'] = 'grouping_key'
  @_hash['unit_amount'] = 'unit_amount'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb', line 34

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb', line 67

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.tier_lower_bound,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.grouping_key,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.unit_amount,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['tier_lower_bound'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['grouping_key'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['unit_amount'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tier_lower_bound: #{@tier_lower_bound.inspect}, grouping_key:"\
  " #{@grouping_key.inspect}, unit_amount: #{@unit_amount.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/api_reference/models/cumulative_grouped_bulk_dimension_value.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tier_lower_bound: #{@tier_lower_bound}, grouping_key: #{@grouping_key},"\
  " unit_amount: #{@unit_amount}>"
end