Class: ApiReference::Customers
- Defined in:
- lib/api_reference/models/customers.rb
Overview
Customers Model.
Instance Attribute Summary collapse
-
#data ⇒ Array[Customer]
TODO: Write general description for this method.
-
#pagination_metadata ⇒ PaginationMetadata
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(data:, pagination_metadata:, additional_properties: nil) ⇒ Customers
constructor
A new instance of Customers.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(data:, pagination_metadata:, additional_properties: nil) ⇒ Customers
Returns a new instance of Customers.
38 39 40 41 42 43 44 45 |
# File 'lib/api_reference/models/customers.rb', line 38 def initialize(data:, pagination_metadata:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @data = data @pagination_metadata = @additional_properties = additional_properties end |
Instance Attribute Details
#data ⇒ Array[Customer]
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/customers.rb', line 14 def data @data end |
#pagination_metadata ⇒ PaginationMetadata
TODO: Write general description for this method
18 19 20 |
# File 'lib/api_reference/models/customers.rb', line 18 def @pagination_metadata end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/api_reference/models/customers.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it data = nil unless hash['data'].nil? data = [] hash['data'].each do |structure| data << (Customer.from_hash(structure) if structure) end end data = nil unless hash.key?('data') = PaginationMetadata.from_hash(hash['pagination_metadata']) if hash['pagination_metadata'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Customers.new(data: data, pagination_metadata: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/api_reference/models/customers.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['data'] = 'data' @_hash['pagination_metadata'] = 'pagination_metadata' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/api_reference/models/customers.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/api_reference/models/customers.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/api_reference/models/customers.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} data: #{@data.inspect}, pagination_metadata:"\ " #{@pagination_metadata.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/api_reference/models/customers.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} data: #{@data}, pagination_metadata: #{@pagination_metadata},"\ " additional_properties: #{@additional_properties}>" end |