Class: ApiReference::DailyCreditAllowanceMatrixValue
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::DailyCreditAllowanceMatrixValue
- Defined in:
- lib/api_reference/models/daily_credit_allowance_matrix_value.rb
Overview
Per-dimension credit price for the daily credit allowance model.
Instance Attribute Summary collapse
-
#dimension_values ⇒ Array[String]
One or two matrix keys to filter usage to this value by.
-
#unit_amount ⇒ String
Credits charged per unit of usage matching the specified dimension_values.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(unit_amount:, dimension_values:) ⇒ DailyCreditAllowanceMatrixValue
constructor
A new instance of DailyCreditAllowanceMatrixValue.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(unit_amount:, dimension_values:) ⇒ DailyCreditAllowanceMatrixValue
Returns a new instance of DailyCreditAllowanceMatrixValue.
39 40 41 42 |
# File 'lib/api_reference/models/daily_credit_allowance_matrix_value.rb', line 39 def initialize(unit_amount:, dimension_values:) @unit_amount = unit_amount @dimension_values = dimension_values end |
Instance Attribute Details
#dimension_values ⇒ Array[String]
One or two matrix keys to filter usage to this value by. For example, ["model"] could be used to apply a different credit rate to each AI model.
19 20 21 |
# File 'lib/api_reference/models/daily_credit_allowance_matrix_value.rb', line 19 def dimension_values @dimension_values end |
#unit_amount ⇒ String
Credits charged per unit of usage matching the specified dimension_values
14 15 16 |
# File 'lib/api_reference/models/daily_credit_allowance_matrix_value.rb', line 14 def unit_amount @unit_amount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/api_reference/models/daily_credit_allowance_matrix_value.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. unit_amount = hash.key?('unit_amount') ? hash['unit_amount'] : nil dimension_values = hash.key?('dimension_values') ? hash['dimension_values'] : nil # Create object from extracted values. DailyCreditAllowanceMatrixValue.new(unit_amount: unit_amount, dimension_values: dimension_values) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/api_reference/models/daily_credit_allowance_matrix_value.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['unit_amount'] = 'unit_amount' @_hash['dimension_values'] = 'dimension_values' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/api_reference/models/daily_credit_allowance_matrix_value.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/api_reference/models/daily_credit_allowance_matrix_value.rb', line 30 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/api_reference/models/daily_credit_allowance_matrix_value.rb', line 60 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.unit_amount, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.dimension_values, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['unit_amount'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['dimension_values'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/api_reference/models/daily_credit_allowance_matrix_value.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} unit_amount: #{@unit_amount.inspect}, dimension_values:"\ " #{@dimension_values.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 |
# File 'lib/api_reference/models/daily_credit_allowance_matrix_value.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} unit_amount: #{@unit_amount}, dimension_values: #{@dimension_values}>" end |