Class: ApiReference::DimensionalPriceGroupApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/api_reference/apis/dimensional_price_group_api.rb

Overview

DimensionalPriceGroupApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from ApiReference::BaseApi

Instance Method Details

#create_dimensional_price_group(body) ⇒ ApiResponse

A dimensional price group is used to partition the result of a billable metric by a set of dimensions. Prices in a price group must specify the partition used to derive their usage. For example, suppose we have a billable metric that measures the number of widgets used and we want to charge differently depending on the color of the widget. We can create a price group with a dimension "color" and two prices: one that charges $10 per red widget and one that charges $20 per blue widget. description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/api_reference/apis/dimensional_price_group_api.rb', line 62

def create_dimensional_price_group(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/dimensional_price_groups',
                                 Server::DEFAULT)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('APIKeyAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DimensionalPriceGroup.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             APIException)
                .local_error('401',
                             'Unauthorized',
                             AuthorizationErrorException)
                .local_error('404',
                             'Not Found',
                             APIException)
                .local_error('409',
                             'Conflict',
                             IdempotencyRequestMismatchException)
                .local_error('413',
                             'Content Too Large',
                             APIException)
                .local_error('429',
                             'Too Many Requests',
                             TooManyRequestsException)
                .local_error('500',
                             'Internal Server Error',
                             ServerErrorException))
    .execute
end

#fetch_dimensional_price_group(dimensional_price_group_id) ⇒ ApiResponse

TODO: type endpoint description here description here

Parameters:

  • dimensional_price_group_id (String)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/api_reference/apis/dimensional_price_group_api.rb', line 199

def fetch_dimensional_price_group(dimensional_price_group_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/dimensional_price_groups/{dimensional_price_group_id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(dimensional_price_group_id, key: 'dimensional_price_group_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('APIKeyAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DimensionalPriceGroup.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             APIException)
                .local_error('401',
                             'Unauthorized',
                             AuthorizationErrorException)
                .local_error('404',
                             'Not Found',
                             APIException)
                .local_error('409',
                             'Conflict',
                             IdempotencyRequestMismatchException)
                .local_error('413',
                             'Content Too Large',
                             APIException)
                .local_error('429',
                             'Too Many Requests',
                             TooManyRequestsException)
                .local_error('500',
                             'Internal Server Error',
                             ServerErrorException))
    .execute
end

#fetch_dimensional_price_group_external_id(external_dimensional_price_group_id) ⇒ ApiResponse

TODO: type endpoint description here TODO: type description here

Parameters:

  • external_dimensional_price_group_id (String)

    Required parameter:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/api_reference/apis/dimensional_price_group_api.rb', line 105

def fetch_dimensional_price_group_external_id(external_dimensional_price_group_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/dimensional_price_groups/external_dimensional_price_group_id/{external_dimensional_price_group_id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(external_dimensional_price_group_id, key: 'external_dimensional_price_group_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('APIKeyAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DimensionalPriceGroup.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             APIException)
                .local_error('401',
                             'Unauthorized',
                             AuthorizationErrorException)
                .local_error('404',
                             'Not Found',
                             APIException)
                .local_error('409',
                             'Conflict',
                             IdempotencyRequestMismatchException)
                .local_error('413',
                             'Content Too Large',
                             APIException)
                .local_error('429',
                             'Too Many Requests',
                             TooManyRequestsException)
                .local_error('500',
                             'Internal Server Error',
                             ServerErrorException))
    .execute
end

#list_dimensional_price_groups(limit: 20, cursor: nil) ⇒ ApiResponse

TODO: type endpoint description here

Parameters:

  • limit (Integer) (defaults to: 20)

    Optional parameter: Example:20

  • cursor (String) (defaults to: nil)

    Optional parameter: TODO: type description here

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/api_reference/apis/dimensional_price_group_api.rb', line 13

def list_dimensional_price_groups(limit: 20,
                                  cursor: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/dimensional_price_groups',
                                 Server::DEFAULT)
               .query_param(new_parameter(limit, key: 'limit'))
               .query_param(new_parameter(cursor, key: 'cursor'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('APIKeyAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DimensionalPriceGroups.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             APIException)
                .local_error('401',
                             'Unauthorized',
                             AuthorizationErrorException)
                .local_error('404',
                             'Not Found',
                             APIException)
                .local_error('409',
                             'Conflict',
                             IdempotencyRequestMismatchException)
                .local_error('413',
                             'Content Too Large',
                             APIException)
                .local_error('429',
                             'Too Many Requests',
                             TooManyRequestsException)
                .local_error('500',
                             'Internal Server Error',
                             ServerErrorException))
    .execute
end

#update_dimensional_price_group(dimensional_price_group_id, body) ⇒ ApiResponse

This endpoint can be used to update the external_dimensional_price_group_id and metadata of an existing dimensional price group. Other fields on a dimensional price group are currently immutable. description here description here

Parameters:

  • dimensional_price_group_id (String)

    Required parameter: TODO: type

  • body (EditDimensionalPriceGroup)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/api_reference/apis/dimensional_price_group_api.rb', line 246

def update_dimensional_price_group(dimensional_price_group_id,
                                   body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/dimensional_price_groups/{dimensional_price_group_id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(dimensional_price_group_id, key: 'dimensional_price_group_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('APIKeyAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DimensionalPriceGroup.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             APIException)
                .local_error('401',
                             'Unauthorized',
                             AuthorizationErrorException)
                .local_error('404',
                             'Not Found',
                             APIException)
                .local_error('409',
                             'Conflict',
                             IdempotencyRequestMismatchException)
                .local_error('413',
                             'Content Too Large',
                             APIException)
                .local_error('429',
                             'Too Many Requests',
                             TooManyRequestsException)
                .local_error('500',
                             'Internal Server Error',
                             ServerErrorException))
    .execute
end

#update_dimensional_price_group_external(external_dimensional_price_group_id, body) ⇒ ApiResponse

This endpoint can be used to update the external_dimensional_price_group_id and metadata of an existing dimensional price group. Other fields on a dimensional price group are currently immutable. TODO: type description here description here

Parameters:

  • external_dimensional_price_group_id (String)

    Required parameter:

  • body (EditDimensionalPriceGroup)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/api_reference/apis/dimensional_price_group_api.rb', line 152

def update_dimensional_price_group_external(external_dimensional_price_group_id,
                                            body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/dimensional_price_groups/external_dimensional_price_group_id/{external_dimensional_price_group_id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(external_dimensional_price_group_id, key: 'external_dimensional_price_group_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('APIKeyAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DimensionalPriceGroup.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             APIException)
                .local_error('401',
                             'Unauthorized',
                             AuthorizationErrorException)
                .local_error('404',
                             'Not Found',
                             APIException)
                .local_error('409',
                             'Conflict',
                             IdempotencyRequestMismatchException)
                .local_error('413',
                             'Content Too Large',
                             APIException)
                .local_error('429',
                             'Too Many Requests',
                             TooManyRequestsException)
                .local_error('500',
                             'Internal Server Error',
                             ServerErrorException))
    .execute
end