Class: ApiReference::EvaluatePriceGroup
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::EvaluatePriceGroup
- Defined in:
- lib/api_reference/models/evaluate_price_group.rb
Overview
EvaluatePriceGroup Model.
Instance Attribute Summary collapse
-
#amount ⇒ String
The price's output for the group.
-
#grouping_values ⇒ Array[Object]
The values for the group in the order specified by
grouping_keys. -
#quantity ⇒ Float
The price's usage quantity for the group.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(grouping_values:, quantity:, amount:, additional_properties: nil) ⇒ EvaluatePriceGroup
constructor
A new instance of EvaluatePriceGroup.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(grouping_values:, quantity:, amount:, additional_properties: nil) ⇒ EvaluatePriceGroup
Returns a new instance of EvaluatePriceGroup.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/api_reference/models/evaluate_price_group.rb', line 43 def initialize(grouping_values:, quantity:, amount:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @grouping_values = grouping_values @quantity = quantity @amount = amount @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ String
The price's output for the group
22 23 24 |
# File 'lib/api_reference/models/evaluate_price_group.rb', line 22 def amount @amount end |
#grouping_values ⇒ Array[Object]
The values for the group in the order specified by grouping_keys
14 15 16 |
# File 'lib/api_reference/models/evaluate_price_group.rb', line 14 def grouping_values @grouping_values end |
#quantity ⇒ Float
The price's usage quantity for the group
18 19 20 |
# File 'lib/api_reference/models/evaluate_price_group.rb', line 18 def quantity @quantity end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/api_reference/models/evaluate_price_group.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. grouping_values = hash.key?('grouping_values') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:EvaluatePriceGroupGroupingValues), hash['grouping_values'] ) : nil quantity = hash.key?('quantity') ? hash['quantity'] : nil amount = hash.key?('amount') ? hash['amount'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. EvaluatePriceGroup.new(grouping_values: grouping_values, quantity: quantity, amount: amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/api_reference/models/evaluate_price_group.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['grouping_values'] = 'grouping_values' @_hash['quantity'] = 'quantity' @_hash['amount'] = 'amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/api_reference/models/evaluate_price_group.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/api_reference/models/evaluate_price_group.rb', line 34 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/api_reference/models/evaluate_price_group.rb', line 81 def self.validate(value) if value.instance_of? self return ( UnionTypeLookUp.get(:EvaluatePriceGroupGroupingValues) .validate(value.grouping_values) and APIHelper.valid_type?(value.quantity, ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value.amount, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( UnionTypeLookUp.get(:EvaluatePriceGroupGroupingValues) .validate(value['grouping_values']) and APIHelper.valid_type?(value['quantity'], ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value['amount'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
113 114 115 116 117 118 |
# File 'lib/api_reference/models/evaluate_price_group.rb', line 113 def inspect class_name = self.class.name.split('::').last "<#{class_name} grouping_values: #{@grouping_values.inspect}, quantity:"\ " #{@quantity.inspect}, amount: #{@amount.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 |
# File 'lib/api_reference/models/evaluate_price_group.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} grouping_values: #{@grouping_values}, quantity: #{@quantity}, amount:"\ " #{@amount}, additional_properties: #{@additional_properties}>" end |