Class: ApiReference::FeatureNotAvailableError
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::FeatureNotAvailableError
- Defined in:
- lib/api_reference/models/feature_not_available_error.rb
Overview
FeatureNotAvailableError Model.
Instance Attribute Summary collapse
-
#detail ⇒ String
TODO: Write general description for this method.
-
#status ⇒ Integer
readonly
TODO: Write general description for this method.
-
#title ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
readonly
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(detail: SKIP, title: SKIP, additional_properties: nil) ⇒ FeatureNotAvailableError
constructor
A new instance of FeatureNotAvailableError.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(detail: SKIP, title: SKIP, additional_properties: nil) ⇒ FeatureNotAvailableError
Returns a new instance of FeatureNotAvailableError.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/api_reference/models/feature_not_available_error.rb', line 54 def initialize(detail: SKIP, title: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = 'https://docs.withorb.com/reference/error-responses#404-feature-not-available' @status = 400 @detail = detail unless detail == SKIP @title = title unless title == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#detail ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/api_reference/models/feature_not_available_error.rb', line 22 def detail @detail end |
#status ⇒ Integer (readonly)
TODO: Write general description for this method
18 19 20 |
# File 'lib/api_reference/models/feature_not_available_error.rb', line 18 def status @status end |
#title ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/api_reference/models/feature_not_available_error.rb', line 26 def title @title end |
#type ⇒ String (readonly)
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/feature_not_available_error.rb', line 14 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/api_reference/models/feature_not_available_error.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. detail = hash.key?('detail') ? hash['detail'] : SKIP title = hash.key?('title') ? hash['title'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FeatureNotAvailableError.new(detail: detail, title: title, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/api_reference/models/feature_not_available_error.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['status'] = 'status' @_hash['detail'] = 'detail' @_hash['title'] = 'title' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 50 51 52 |
# File 'lib/api_reference/models/feature_not_available_error.rb', line 47 def self.nullables %w[ detail title ] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 |
# File 'lib/api_reference/models/feature_not_available_error.rb', line 39 def self.optionals %w[ detail title ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/api_reference/models/feature_not_available_error.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, status: #{@status.inspect}, detail:"\ " #{@detail.inspect}, title: #{@title.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/api_reference/models/feature_not_available_error.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, status: #{@status}, detail: #{@detail}, title: #{@title},"\ " additional_properties: #{@additional_properties}>" end |