Class: ApiReference::FetchSubscriptionScheduleQueryParams
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::FetchSubscriptionScheduleQueryParams
- Defined in:
- lib/api_reference/models/fetch_subscription_schedule_query_params.rb
Overview
FetchSubscriptionScheduleQueryParams Model.
Instance Attribute Summary collapse
-
#cursor ⇒ String
Cursor for pagination.
-
#limit ⇒ Integer
The number of items to fetch.
-
#start_date_gt ⇒ DateTime
Cursor for pagination.
-
#start_date_gte ⇒ DateTime
Cursor for pagination.
-
#start_date_lt ⇒ DateTime
Cursor for pagination.
-
#start_date_lte ⇒ DateTime
Cursor for pagination.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(limit: 20, cursor: SKIP, start_date_gte: SKIP, start_date_gt: SKIP, start_date_lt: SKIP, start_date_lte: SKIP) ⇒ FetchSubscriptionScheduleQueryParams
constructor
A new instance of FetchSubscriptionScheduleQueryParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_start_date_gt ⇒ Object
- #to_custom_start_date_gte ⇒ Object
- #to_custom_start_date_lt ⇒ Object
- #to_custom_start_date_lte ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(limit: 20, cursor: SKIP, start_date_gte: SKIP, start_date_gt: SKIP, start_date_lt: SKIP, start_date_lte: SKIP) ⇒ FetchSubscriptionScheduleQueryParams
Returns a new instance of FetchSubscriptionScheduleQueryParams.
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 77 def initialize(limit: 20, cursor: SKIP, start_date_gte: SKIP, start_date_gt: SKIP, start_date_lt: SKIP, start_date_lte: SKIP) @limit = limit unless limit == SKIP @cursor = cursor unless cursor == SKIP @start_date_gte = start_date_gte unless start_date_gte == SKIP @start_date_gt = start_date_gt unless start_date_gt == SKIP @start_date_lt = start_date_lt unless start_date_lt == SKIP @start_date_lte = start_date_lte unless start_date_lte == SKIP end |
Instance Attribute Details
#cursor ⇒ String
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
20 21 22 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 20 def cursor @cursor end |
#limit ⇒ Integer
The number of items to fetch. Defaults to 20.
15 16 17 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 15 def limit @limit end |
#start_date_gt ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
30 31 32 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 30 def start_date_gt @start_date_gt end |
#start_date_gte ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
25 26 27 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 25 def start_date_gte @start_date_gte end |
#start_date_lt ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
35 36 37 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 35 def start_date_lt @start_date_lt end |
#start_date_lte ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
40 41 42 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 40 def start_date_lte @start_date_lte end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 89 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. limit = hash['limit'] ||= 20 cursor = hash.key?('cursor') ? hash['cursor'] : SKIP start_date_gte = if hash.key?('start_date[gte]') (DateTimeHelper.from_rfc3339(hash['start_date[gte]']) if hash['start_date[gte]']) else SKIP end start_date_gt = if hash.key?('start_date[gt]') (DateTimeHelper.from_rfc3339(hash['start_date[gt]']) if hash['start_date[gt]']) else SKIP end start_date_lt = if hash.key?('start_date[lt]') (DateTimeHelper.from_rfc3339(hash['start_date[lt]']) if hash['start_date[lt]']) else SKIP end start_date_lte = if hash.key?('start_date[lte]') (DateTimeHelper.from_rfc3339(hash['start_date[lte]']) if hash['start_date[lte]']) else SKIP end # Create object from extracted values. FetchSubscriptionScheduleQueryParams.new(limit: limit, cursor: cursor, start_date_gte: start_date_gte, start_date_gt: start_date_gt, start_date_lt: start_date_lt, start_date_lte: start_date_lte) end |
.names ⇒ Object
A mapping from model property names to API property names.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 43 def self.names @_hash = {} if @_hash.nil? @_hash['limit'] = 'limit' @_hash['cursor'] = 'cursor' @_hash['start_date_gte'] = 'start_date[gte]' @_hash['start_date_gt'] = 'start_date[gt]' @_hash['start_date_lt'] = 'start_date[lt]' @_hash['start_date_lte'] = 'start_date[lte]' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 70 71 72 73 74 75 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 67 def self.nullables %w[ cursor start_date_gte start_date_gt start_date_lt start_date_lte ] end |
.optionals ⇒ Object
An array for optional fields
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 55 def self.optionals %w[ limit cursor start_date_gte start_date_gt start_date_lt start_date_lte ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
150 151 152 153 154 155 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 150 def inspect class_name = self.class.name.split('::').last "<#{class_name} limit: #{@limit.inspect}, cursor: #{@cursor.inspect}, start_date_gte:"\ " #{@start_date_gte.inspect}, start_date_gt: #{@start_date_gt.inspect}, start_date_lt:"\ " #{@start_date_lt.inspect}, start_date_lte: #{@start_date_lte.inspect}>" end |
#to_custom_start_date_gt ⇒ Object
129 130 131 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 129 def to_custom_start_date_gt DateTimeHelper.to_rfc3339(start_date_gt) end |
#to_custom_start_date_gte ⇒ Object
125 126 127 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 125 def to_custom_start_date_gte DateTimeHelper.to_rfc3339(start_date_gte) end |
#to_custom_start_date_lt ⇒ Object
133 134 135 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 133 def to_custom_start_date_lt DateTimeHelper.to_rfc3339(start_date_lt) end |
#to_custom_start_date_lte ⇒ Object
137 138 139 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 137 def to_custom_start_date_lte DateTimeHelper.to_rfc3339(start_date_lte) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
142 143 144 145 146 147 |
# File 'lib/api_reference/models/fetch_subscription_schedule_query_params.rb', line 142 def to_s class_name = self.class.name.split('::').last "<#{class_name} limit: #{@limit}, cursor: #{@cursor}, start_date_gte: #{@start_date_gte},"\ " start_date_gt: #{@start_date_gt}, start_date_lt: #{@start_date_lt}, start_date_lte:"\ " #{@start_date_lte}>" end |