Class: ApiReference::FixedFeeQuantityScheduleEntry

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb

Overview

FixedFeeQuantityScheduleEntry Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(price_id:, start_date:, end_date:, quantity:, additional_properties: nil) ⇒ FixedFeeQuantityScheduleEntry

Returns a new instance of FixedFeeQuantityScheduleEntry.



51
52
53
54
55
56
57
58
59
60
61
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 51

def initialize(price_id:, start_date:, end_date:, quantity:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @price_id = price_id
  @start_date = start_date
  @end_date = end_date
  @quantity = quantity
  @additional_properties = additional_properties
end

Instance Attribute Details

#end_dateDateTime

TODO: Write general description for this method

Returns:

  • (DateTime)


23
24
25
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 23

def end_date
  @end_date
end

#price_idString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 15

def price_id
  @price_id
end

#quantityFloat

TODO: Write general description for this method

Returns:

  • (Float)


27
28
29
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 27

def quantity
  @quantity
end

#start_dateDateTime

TODO: Write general description for this method

Returns:

  • (DateTime)


19
20
21
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 19

def start_date
  @start_date
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 64

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  price_id = hash.key?('price_id') ? hash['price_id'] : nil
  start_date = if hash.key?('start_date')
                 (DateTimeHelper.from_rfc3339(hash['start_date']) if hash['start_date'])
               end
  end_date = if hash.key?('end_date')
               (DateTimeHelper.from_rfc3339(hash['end_date']) if hash['end_date'])
             end
  quantity = hash.key?('quantity') ? hash['quantity'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FixedFeeQuantityScheduleEntry.new(price_id: price_id,
                                    start_date: start_date,
                                    end_date: end_date,
                                    quantity: quantity,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
37
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['price_id'] = 'price_id'
  @_hash['start_date'] = 'start_date'
  @_hash['end_date'] = 'end_date'
  @_hash['quantity'] = 'quantity'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
48
49
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 45

def self.nullables
  %w[
    end_date
  ]
end

.optionalsObject

An array for optional fields



40
41
42
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 40

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 102

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.price_id,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.start_date,
                              ->(val) { val.instance_of? DateTime }) and
        APIHelper.valid_type?(value.end_date,
                              ->(val) { val.instance_of? DateTime }) and
        APIHelper.valid_type?(value.quantity,
                              ->(val) { val.instance_of? Float })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['price_id'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['start_date'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['end_date'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['quantity'],
                            ->(val) { val.instance_of? Float })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



138
139
140
141
142
143
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 138

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} price_id: #{@price_id.inspect}, start_date: #{@start_date.inspect},"\
  " end_date: #{@end_date.inspect}, quantity: #{@quantity.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_custom_end_dateObject



96
97
98
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 96

def to_custom_end_date
  DateTimeHelper.to_rfc3339(end_date)
end

#to_custom_start_dateObject



92
93
94
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 92

def to_custom_start_date
  DateTimeHelper.to_rfc3339(start_date)
end

#to_sObject

Provides a human-readable string representation of the object.



131
132
133
134
135
# File 'lib/api_reference/models/fixed_fee_quantity_schedule_entry.rb', line 131

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} price_id: #{@price_id}, start_date: #{@start_date}, end_date: #{@end_date},"\
  " quantity: #{@quantity}, additional_properties: #{@additional_properties}>"
end