Class: ApiReference::GroupedAllocationConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/grouped_allocation_config.rb

Overview

Configuration for grouped allocation pricing

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(grouping_key:, overage_unit_rate:, allocation:) ⇒ GroupedAllocationConfig

Returns a new instance of GroupedAllocationConfig.



43
44
45
46
47
# File 'lib/api_reference/models/grouped_allocation_config.rb', line 43

def initialize(grouping_key:, overage_unit_rate:, allocation:)
  @grouping_key = grouping_key
  @overage_unit_rate = overage_unit_rate
  @allocation = allocation
end

Instance Attribute Details

#allocationString

Usage allocation per group

Returns:

  • (String)


22
23
24
# File 'lib/api_reference/models/grouped_allocation_config.rb', line 22

def allocation
  @allocation
end

#grouping_keyString

How to determine the groups that should each be allocated some quantity

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/grouped_allocation_config.rb', line 14

def grouping_key
  @grouping_key
end

#overage_unit_rateString

Unit rate for post-allocation

Returns:

  • (String)


18
19
20
# File 'lib/api_reference/models/grouped_allocation_config.rb', line 18

def overage_unit_rate
  @overage_unit_rate
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/api_reference/models/grouped_allocation_config.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  grouping_key = hash.key?('grouping_key') ? hash['grouping_key'] : nil
  overage_unit_rate =
    hash.key?('overage_unit_rate') ? hash['overage_unit_rate'] : nil
  allocation = hash.key?('allocation') ? hash['allocation'] : nil

  # Create object from extracted values.
  GroupedAllocationConfig.new(grouping_key: grouping_key,
                              overage_unit_rate: overage_unit_rate,
                              allocation: allocation)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/api_reference/models/grouped_allocation_config.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['grouping_key'] = 'grouping_key'
  @_hash['overage_unit_rate'] = 'overage_unit_rate'
  @_hash['allocation'] = 'allocation'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/api_reference/models/grouped_allocation_config.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/api_reference/models/grouped_allocation_config.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



73
74
75
76
77
# File 'lib/api_reference/models/grouped_allocation_config.rb', line 73

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} grouping_key: #{@grouping_key.inspect}, overage_unit_rate:"\
  " #{@overage_unit_rate.inspect}, allocation: #{@allocation.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



66
67
68
69
70
# File 'lib/api_reference/models/grouped_allocation_config.rb', line 66

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} grouping_key: #{@grouping_key}, overage_unit_rate: #{@overage_unit_rate},"\
  " allocation: #{@allocation}>"
end