Class: ApiReference::GroupedSubscriptionUsage
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::GroupedSubscriptionUsage
- Defined in:
- lib/api_reference/models/grouped_subscription_usage.rb
Overview
GroupedSubscriptionUsage Model.
Instance Attribute Summary collapse
-
#data ⇒ Array[GroupedSubscriptionUsageRecord]
TODO: Write general description for this method.
-
#pagination_metadata ⇒ PaginationMetadata
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(data:, pagination_metadata: SKIP, additional_properties: nil) ⇒ GroupedSubscriptionUsage
constructor
A new instance of GroupedSubscriptionUsage.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(data:, pagination_metadata: SKIP, additional_properties: nil) ⇒ GroupedSubscriptionUsage
Returns a new instance of GroupedSubscriptionUsage.
42 43 44 45 46 47 48 49 |
# File 'lib/api_reference/models/grouped_subscription_usage.rb', line 42 def initialize(data:, pagination_metadata: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @data = data @pagination_metadata = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#data ⇒ Array[GroupedSubscriptionUsageRecord]
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/grouped_subscription_usage.rb', line 14 def data @data end |
#pagination_metadata ⇒ PaginationMetadata
TODO: Write general description for this method
18 19 20 |
# File 'lib/api_reference/models/grouped_subscription_usage.rb', line 18 def @pagination_metadata end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/api_reference/models/grouped_subscription_usage.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it data = nil unless hash['data'].nil? data = [] hash['data'].each do |structure| data << (GroupedSubscriptionUsageRecord.from_hash(structure) if structure) end end data = nil unless hash.key?('data') = PaginationMetadata.from_hash(hash['pagination_metadata']) if hash['pagination_metadata'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GroupedSubscriptionUsage.new(data: data, pagination_metadata: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/api_reference/models/grouped_subscription_usage.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['data'] = 'data' @_hash['pagination_metadata'] = 'pagination_metadata' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 39 40 |
# File 'lib/api_reference/models/grouped_subscription_usage.rb', line 36 def self.nullables %w[ pagination_metadata ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/api_reference/models/grouped_subscription_usage.rb', line 29 def self.optionals %w[ pagination_metadata ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/api_reference/models/grouped_subscription_usage.rb', line 84 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.data, ->(val) { GroupedSubscriptionUsageRecord.validate(val) }, is_model_hash: true, is_inner_model_hash: true) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['data'], ->(val) { GroupedSubscriptionUsageRecord.validate(val) }, is_model_hash: true, is_inner_model_hash: true) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
108 109 110 111 112 |
# File 'lib/api_reference/models/grouped_subscription_usage.rb', line 108 def inspect class_name = self.class.name.split('::').last "<#{class_name} data: #{@data.inspect}, pagination_metadata:"\ " #{@pagination_metadata.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
101 102 103 104 105 |
# File 'lib/api_reference/models/grouped_subscription_usage.rb', line 101 def to_s class_name = self.class.name.split('::').last "<#{class_name} data: #{@data}, pagination_metadata: #{@pagination_metadata},"\ " additional_properties: #{@additional_properties}>" end |