Class: ApiReference::GroupedTieredConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::GroupedTieredConfig
- Defined in:
- lib/api_reference/models/grouped_tiered_config.rb
Overview
Configuration for grouped tiered pricing
Instance Attribute Summary collapse
-
#grouping_key ⇒ String
The billable metric property used to group before tiering.
-
#tiers ⇒ Array[GroupedTieredTier]
Apply tiered pricing to each segment generated after grouping with the provided key.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tiers:, grouping_key:) ⇒ GroupedTieredConfig
constructor
A new instance of GroupedTieredConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tiers:, grouping_key:) ⇒ GroupedTieredConfig
Returns a new instance of GroupedTieredConfig.
39 40 41 42 |
# File 'lib/api_reference/models/grouped_tiered_config.rb', line 39 def initialize(tiers:, grouping_key:) @tiers = tiers @grouping_key = grouping_key end |
Instance Attribute Details
#grouping_key ⇒ String
The billable metric property used to group before tiering
19 20 21 |
# File 'lib/api_reference/models/grouped_tiered_config.rb', line 19 def grouping_key @grouping_key end |
#tiers ⇒ Array[GroupedTieredTier]
Apply tiered pricing to each segment generated after grouping with the provided key
15 16 17 |
# File 'lib/api_reference/models/grouped_tiered_config.rb', line 15 def tiers @tiers end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/api_reference/models/grouped_tiered_config.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it tiers = nil unless hash['tiers'].nil? tiers = [] hash['tiers'].each do |structure| tiers << (GroupedTieredTier.from_hash(structure) if structure) end end tiers = nil unless hash.key?('tiers') grouping_key = hash.key?('grouping_key') ? hash['grouping_key'] : nil # Create object from extracted values. GroupedTieredConfig.new(tiers: tiers, grouping_key: grouping_key) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/api_reference/models/grouped_tiered_config.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['tiers'] = 'tiers' @_hash['grouping_key'] = 'grouping_key' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/api_reference/models/grouped_tiered_config.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/api_reference/models/grouped_tiered_config.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 |
# File 'lib/api_reference/models/grouped_tiered_config.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} tiers: #{@tiers.inspect}, grouping_key: #{@grouping_key.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 |
# File 'lib/api_reference/models/grouped_tiered_config.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} tiers: #{@tiers}, grouping_key: #{@grouping_key}>" end |