Class: ApiReference::GroupedTieredPackageTierItem

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/grouped_tiered_package_tier_item.rb

Overview

Configuration for a single tier

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tier_lower_bound:, per_unit:) ⇒ GroupedTieredPackageTierItem

Returns a new instance of GroupedTieredPackageTierItem.



38
39
40
41
# File 'lib/api_reference/models/grouped_tiered_package_tier_item.rb', line 38

def initialize(tier_lower_bound:, per_unit:)
  @tier_lower_bound = tier_lower_bound
  @per_unit = per_unit
end

Instance Attribute Details

#per_unitString

Per package

Returns:

  • (String)


18
19
20
# File 'lib/api_reference/models/grouped_tiered_package_tier_item.rb', line 18

def per_unit
  @per_unit
end

#tier_lower_boundString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/grouped_tiered_package_tier_item.rb', line 14

def tier_lower_bound
  @tier_lower_bound
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/api_reference/models/grouped_tiered_package_tier_item.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tier_lower_bound =
    hash.key?('tier_lower_bound') ? hash['tier_lower_bound'] : nil
  per_unit = hash.key?('per_unit') ? hash['per_unit'] : nil

  # Create object from extracted values.
  GroupedTieredPackageTierItem.new(tier_lower_bound: tier_lower_bound,
                                   per_unit: per_unit)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/grouped_tiered_package_tier_item.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tier_lower_bound'] = 'tier_lower_bound'
  @_hash['per_unit'] = 'per_unit'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/api_reference/models/grouped_tiered_package_tier_item.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/api_reference/models/grouped_tiered_package_tier_item.rb', line 29

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/api_reference/models/grouped_tiered_package_tier_item.rb', line 59

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.tier_lower_bound,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.per_unit,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['tier_lower_bound'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['per_unit'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/api_reference/models/grouped_tiered_package_tier_item.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tier_lower_bound: #{@tier_lower_bound.inspect}, per_unit:"\
  " #{@per_unit.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
# File 'lib/api_reference/models/grouped_tiered_package_tier_item.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tier_lower_bound: #{@tier_lower_bound}, per_unit: #{@per_unit}>"
end