Class: ApiReference::GroupedWithProratedMinimumConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::GroupedWithProratedMinimumConfig
- Defined in:
- lib/api_reference/models/grouped_with_prorated_minimum_config.rb
Overview
Configuration for grouped with prorated minimum pricing
Instance Attribute Summary collapse
-
#grouping_key ⇒ String
How to determine the groups that should each have a minimum.
-
#minimum ⇒ String
The minimum amount to charge per group.
-
#unit_rate ⇒ String
The amount to charge per unit.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(grouping_key:, unit_rate:, minimum:) ⇒ GroupedWithProratedMinimumConfig
constructor
A new instance of GroupedWithProratedMinimumConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(grouping_key:, unit_rate:, minimum:) ⇒ GroupedWithProratedMinimumConfig
Returns a new instance of GroupedWithProratedMinimumConfig.
43 44 45 46 47 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config.rb', line 43 def initialize(grouping_key:, unit_rate:, minimum:) @grouping_key = grouping_key @unit_rate = unit_rate @minimum = minimum end |
Instance Attribute Details
#grouping_key ⇒ String
How to determine the groups that should each have a minimum
14 15 16 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config.rb', line 14 def grouping_key @grouping_key end |
#minimum ⇒ String
The minimum amount to charge per group
22 23 24 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config.rb', line 22 def minimum @minimum end |
#unit_rate ⇒ String
The amount to charge per unit
18 19 20 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config.rb', line 18 def unit_rate @unit_rate end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. grouping_key = hash.key?('grouping_key') ? hash['grouping_key'] : nil unit_rate = hash.key?('unit_rate') ? hash['unit_rate'] : nil minimum = hash.key?('minimum') ? hash['minimum'] : nil # Create object from extracted values. GroupedWithProratedMinimumConfig.new(grouping_key: grouping_key, unit_rate: unit_rate, minimum: minimum) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['grouping_key'] = 'grouping_key' @_hash['unit_rate'] = 'unit_rate' @_hash['minimum'] = 'minimum' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} grouping_key: #{@grouping_key.inspect}, unit_rate: #{@unit_rate.inspect},"\ " minimum: #{@minimum.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 69 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} grouping_key: #{@grouping_key}, unit_rate: #{@unit_rate}, minimum:"\ " #{@minimum}>" end |