Class: ApiReference::GroupedWithProratedMinimumConfig1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::GroupedWithProratedMinimumConfig1
- Defined in:
- lib/api_reference/models/grouped_with_prorated_minimum_config1.rb
Overview
Configuration for grouped_with_prorated_minimum pricing
Instance Attribute Summary collapse
-
#grouping_key ⇒ String
How to determine the groups that should each have a minimum.
-
#minimum ⇒ String
The minimum amount to charge per group.
-
#unit_rate ⇒ String
The amount to charge per unit.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(grouping_key:, unit_rate:, minimum:) ⇒ GroupedWithProratedMinimumConfig1
constructor
A new instance of GroupedWithProratedMinimumConfig1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(grouping_key:, unit_rate:, minimum:) ⇒ GroupedWithProratedMinimumConfig1
Returns a new instance of GroupedWithProratedMinimumConfig1.
43 44 45 46 47 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config1.rb', line 43 def initialize(grouping_key:, unit_rate:, minimum:) @grouping_key = grouping_key @unit_rate = unit_rate @minimum = minimum end |
Instance Attribute Details
#grouping_key ⇒ String
How to determine the groups that should each have a minimum
14 15 16 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config1.rb', line 14 def grouping_key @grouping_key end |
#minimum ⇒ String
The minimum amount to charge per group
22 23 24 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config1.rb', line 22 def minimum @minimum end |
#unit_rate ⇒ String
The amount to charge per unit
18 19 20 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config1.rb', line 18 def unit_rate @unit_rate end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config1.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. grouping_key = hash.key?('grouping_key') ? hash['grouping_key'] : nil unit_rate = hash.key?('unit_rate') ? hash['unit_rate'] : nil minimum = hash.key?('minimum') ? hash['minimum'] : nil # Create object from extracted values. GroupedWithProratedMinimumConfig1.new(grouping_key: grouping_key, unit_rate: unit_rate, minimum: minimum) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config1.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['grouping_key'] = 'grouping_key' @_hash['unit_rate'] = 'unit_rate' @_hash['minimum'] = 'minimum' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config1.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config1.rb', line 34 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config1.rb', line 66 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.grouping_key, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.unit_rate, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.minimum, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['grouping_key'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['unit_rate'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['minimum'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config1.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} grouping_key: #{@grouping_key.inspect}, unit_rate: #{@unit_rate.inspect},"\ " minimum: #{@minimum.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/api_reference/models/grouped_with_prorated_minimum_config1.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} grouping_key: #{@grouping_key}, unit_rate: #{@unit_rate}, minimum:"\ " #{@minimum}>" end |