Class: ApiReference::IssueInvoiceRequestParams

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/issue_invoice_request_params.rb

Overview

IssueInvoiceRequestParams Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(synchronous: false) ⇒ IssueInvoiceRequestParams

Returns a new instance of IssueInvoiceRequestParams.



39
40
41
# File 'lib/api_reference/models/issue_invoice_request_params.rb', line 39

def initialize(synchronous: false)
  @synchronous = synchronous unless synchronous == SKIP
end

Instance Attribute Details

#synchronousTrueClass | FalseClass

If true, the invoice will be issued synchronously. If false, the invoice will be issued asynchronously. The synchronous option is only available for invoices that have no usage fees. If the invoice is configured to sync to an external provider, a successful response from this endpoint guarantees the invoice is present in the provider.

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/api_reference/models/issue_invoice_request_params.rb', line 18

def synchronous
  @synchronous
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
# File 'lib/api_reference/models/issue_invoice_request_params.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  synchronous = hash['synchronous'] ||= false

  # Create object from extracted values.
  IssueInvoiceRequestParams.new(synchronous: synchronous)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
# File 'lib/api_reference/models/issue_invoice_request_params.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['synchronous'] = 'synchronous'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/api_reference/models/issue_invoice_request_params.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



28
29
30
31
32
# File 'lib/api_reference/models/issue_invoice_request_params.rb', line 28

def self.optionals
  %w[
    synchronous
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



61
62
63
64
# File 'lib/api_reference/models/issue_invoice_request_params.rb', line 61

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} synchronous: #{@synchronous.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



55
56
57
58
# File 'lib/api_reference/models/issue_invoice_request_params.rb', line 55

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} synchronous: #{@synchronous}>"
end