Class: ApiReference::ListCustomerBalanceTransactionsQueryParams
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::ListCustomerBalanceTransactionsQueryParams
- Defined in:
- lib/api_reference/models/list_customer_balance_transactions_query_params.rb
Overview
ListCustomerBalanceTransactionsQueryParams Model.
Instance Attribute Summary collapse
-
#cursor ⇒ String
Cursor for pagination.
-
#limit ⇒ Integer
The number of items to fetch.
-
#operation_time_gt ⇒ DateTime
Cursor for pagination.
-
#operation_time_gte ⇒ DateTime
Cursor for pagination.
-
#operation_time_lt ⇒ DateTime
Cursor for pagination.
-
#operation_time_lte ⇒ DateTime
Cursor for pagination.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(limit: 20, cursor: SKIP, operation_time_gte: SKIP, operation_time_gt: SKIP, operation_time_lt: SKIP, operation_time_lte: SKIP) ⇒ ListCustomerBalanceTransactionsQueryParams
constructor
A new instance of ListCustomerBalanceTransactionsQueryParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_operation_time_gt ⇒ Object
- #to_custom_operation_time_gte ⇒ Object
- #to_custom_operation_time_lt ⇒ Object
- #to_custom_operation_time_lte ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(limit: 20, cursor: SKIP, operation_time_gte: SKIP, operation_time_gt: SKIP, operation_time_lt: SKIP, operation_time_lte: SKIP) ⇒ ListCustomerBalanceTransactionsQueryParams
Returns a new instance of ListCustomerBalanceTransactionsQueryParams.
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 77 def initialize(limit: 20, cursor: SKIP, operation_time_gte: SKIP, operation_time_gt: SKIP, operation_time_lt: SKIP, operation_time_lte: SKIP) @limit = limit unless limit == SKIP @cursor = cursor unless cursor == SKIP @operation_time_gte = operation_time_gte unless operation_time_gte == SKIP @operation_time_gt = operation_time_gt unless operation_time_gt == SKIP @operation_time_lt = operation_time_lt unless operation_time_lt == SKIP @operation_time_lte = operation_time_lte unless operation_time_lte == SKIP end |
Instance Attribute Details
#cursor ⇒ String
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
20 21 22 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 20 def cursor @cursor end |
#limit ⇒ Integer
The number of items to fetch. Defaults to 20.
15 16 17 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 15 def limit @limit end |
#operation_time_gt ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
30 31 32 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 30 def operation_time_gt @operation_time_gt end |
#operation_time_gte ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
25 26 27 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 25 def operation_time_gte @operation_time_gte end |
#operation_time_lt ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
35 36 37 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 35 def operation_time_lt @operation_time_lt end |
#operation_time_lte ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
40 41 42 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 40 def operation_time_lte @operation_time_lte end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 89 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. limit = hash['limit'] ||= 20 cursor = hash.key?('cursor') ? hash['cursor'] : SKIP operation_time_gte = if hash.key?('operation_time[gte]') (DateTimeHelper.from_rfc3339(hash['operation_time[gte]']) if hash['operation_time[gte]']) else SKIP end operation_time_gt = if hash.key?('operation_time[gt]') (DateTimeHelper.from_rfc3339(hash['operation_time[gt]']) if hash['operation_time[gt]']) else SKIP end operation_time_lt = if hash.key?('operation_time[lt]') (DateTimeHelper.from_rfc3339(hash['operation_time[lt]']) if hash['operation_time[lt]']) else SKIP end operation_time_lte = if hash.key?('operation_time[lte]') (DateTimeHelper.from_rfc3339(hash['operation_time[lte]']) if hash['operation_time[lte]']) else SKIP end # Create object from extracted values. ListCustomerBalanceTransactionsQueryParams.new(limit: limit, cursor: cursor, operation_time_gte: operation_time_gte, operation_time_gt: operation_time_gt, operation_time_lt: operation_time_lt, operation_time_lte: operation_time_lte) end |
.names ⇒ Object
A mapping from model property names to API property names.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 43 def self.names @_hash = {} if @_hash.nil? @_hash['limit'] = 'limit' @_hash['cursor'] = 'cursor' @_hash['operation_time_gte'] = 'operation_time[gte]' @_hash['operation_time_gt'] = 'operation_time[gt]' @_hash['operation_time_lt'] = 'operation_time[lt]' @_hash['operation_time_lte'] = 'operation_time[lte]' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 70 71 72 73 74 75 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 67 def self.nullables %w[ cursor operation_time_gte operation_time_gt operation_time_lt operation_time_lte ] end |
.optionals ⇒ Object
An array for optional fields
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 55 def self.optionals %w[ limit cursor operation_time_gte operation_time_gt operation_time_lt operation_time_lte ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
150 151 152 153 154 155 156 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 150 def inspect class_name = self.class.name.split('::').last "<#{class_name} limit: #{@limit.inspect}, cursor: #{@cursor.inspect}, operation_time_gte:"\ " #{@operation_time_gte.inspect}, operation_time_gt: #{@operation_time_gt.inspect},"\ " operation_time_lt: #{@operation_time_lt.inspect}, operation_time_lte:"\ " #{@operation_time_lte.inspect}>" end |
#to_custom_operation_time_gt ⇒ Object
129 130 131 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 129 def to_custom_operation_time_gt DateTimeHelper.to_rfc3339(operation_time_gt) end |
#to_custom_operation_time_gte ⇒ Object
125 126 127 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 125 def to_custom_operation_time_gte DateTimeHelper.to_rfc3339(operation_time_gte) end |
#to_custom_operation_time_lt ⇒ Object
133 134 135 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 133 def to_custom_operation_time_lt DateTimeHelper.to_rfc3339(operation_time_lt) end |
#to_custom_operation_time_lte ⇒ Object
137 138 139 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 137 def to_custom_operation_time_lte DateTimeHelper.to_rfc3339(operation_time_lte) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
142 143 144 145 146 147 |
# File 'lib/api_reference/models/list_customer_balance_transactions_query_params.rb', line 142 def to_s class_name = self.class.name.split('::').last "<#{class_name} limit: #{@limit}, cursor: #{@cursor}, operation_time_gte:"\ " #{@operation_time_gte}, operation_time_gt: #{@operation_time_gt}, operation_time_lt:"\ " #{@operation_time_lt}, operation_time_lte: #{@operation_time_lte}>" end |