Class: ApiReference::ListCustomersQueryParams
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::ListCustomersQueryParams
- Defined in:
- lib/api_reference/models/list_customers_query_params.rb
Overview
ListCustomersQueryParams Model.
Instance Attribute Summary collapse
-
#created_at_gt ⇒ DateTime
Cursor for pagination.
-
#created_at_gte ⇒ DateTime
Cursor for pagination.
-
#created_at_lt ⇒ DateTime
Cursor for pagination.
-
#created_at_lte ⇒ DateTime
Cursor for pagination.
-
#cursor ⇒ String
Cursor for pagination.
-
#limit ⇒ Integer
The number of items to fetch.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(limit: 20, cursor: SKIP, created_at_gte: SKIP, created_at_gt: SKIP, created_at_lt: SKIP, created_at_lte: SKIP) ⇒ ListCustomersQueryParams
constructor
A new instance of ListCustomersQueryParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_created_at_gt ⇒ Object
- #to_custom_created_at_gte ⇒ Object
- #to_custom_created_at_lt ⇒ Object
- #to_custom_created_at_lte ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(limit: 20, cursor: SKIP, created_at_gte: SKIP, created_at_gt: SKIP, created_at_lt: SKIP, created_at_lte: SKIP) ⇒ ListCustomersQueryParams
Returns a new instance of ListCustomersQueryParams.
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 77 def initialize(limit: 20, cursor: SKIP, created_at_gte: SKIP, created_at_gt: SKIP, created_at_lt: SKIP, created_at_lte: SKIP) @limit = limit unless limit == SKIP @cursor = cursor unless cursor == SKIP @created_at_gte = created_at_gte unless created_at_gte == SKIP @created_at_gt = created_at_gt unless created_at_gt == SKIP @created_at_lt = created_at_lt unless created_at_lt == SKIP @created_at_lte = created_at_lte unless created_at_lte == SKIP end |
Instance Attribute Details
#created_at_gt ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
30 31 32 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 30 def created_at_gt @created_at_gt end |
#created_at_gte ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
25 26 27 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 25 def created_at_gte @created_at_gte end |
#created_at_lt ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
35 36 37 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 35 def created_at_lt @created_at_lt end |
#created_at_lte ⇒ DateTime
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
40 41 42 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 40 def created_at_lte @created_at_lte end |
#cursor ⇒ String
Cursor for pagination. This can be populated by the next_cursor value
returned from the initial request.
20 21 22 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 20 def cursor @cursor end |
#limit ⇒ Integer
The number of items to fetch. Defaults to 20.
15 16 17 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 15 def limit @limit end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 89 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. limit = hash['limit'] ||= 20 cursor = hash.key?('cursor') ? hash['cursor'] : SKIP created_at_gte = if hash.key?('created_at[gte]') (DateTimeHelper.from_rfc3339(hash['created_at[gte]']) if hash['created_at[gte]']) else SKIP end created_at_gt = if hash.key?('created_at[gt]') (DateTimeHelper.from_rfc3339(hash['created_at[gt]']) if hash['created_at[gt]']) else SKIP end created_at_lt = if hash.key?('created_at[lt]') (DateTimeHelper.from_rfc3339(hash['created_at[lt]']) if hash['created_at[lt]']) else SKIP end created_at_lte = if hash.key?('created_at[lte]') (DateTimeHelper.from_rfc3339(hash['created_at[lte]']) if hash['created_at[lte]']) else SKIP end # Create object from extracted values. ListCustomersQueryParams.new(limit: limit, cursor: cursor, created_at_gte: created_at_gte, created_at_gt: created_at_gt, created_at_lt: created_at_lt, created_at_lte: created_at_lte) end |
.names ⇒ Object
A mapping from model property names to API property names.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 43 def self.names @_hash = {} if @_hash.nil? @_hash['limit'] = 'limit' @_hash['cursor'] = 'cursor' @_hash['created_at_gte'] = 'created_at[gte]' @_hash['created_at_gt'] = 'created_at[gt]' @_hash['created_at_lt'] = 'created_at[lt]' @_hash['created_at_lte'] = 'created_at[lte]' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 70 71 72 73 74 75 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 67 def self.nullables %w[ cursor created_at_gte created_at_gt created_at_lt created_at_lte ] end |
.optionals ⇒ Object
An array for optional fields
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 55 def self.optionals %w[ limit cursor created_at_gte created_at_gt created_at_lt created_at_lte ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
150 151 152 153 154 155 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 150 def inspect class_name = self.class.name.split('::').last "<#{class_name} limit: #{@limit.inspect}, cursor: #{@cursor.inspect}, created_at_gte:"\ " #{@created_at_gte.inspect}, created_at_gt: #{@created_at_gt.inspect}, created_at_lt:"\ " #{@created_at_lt.inspect}, created_at_lte: #{@created_at_lte.inspect}>" end |
#to_custom_created_at_gt ⇒ Object
129 130 131 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 129 def to_custom_created_at_gt DateTimeHelper.to_rfc3339(created_at_gt) end |
#to_custom_created_at_gte ⇒ Object
125 126 127 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 125 def to_custom_created_at_gte DateTimeHelper.to_rfc3339(created_at_gte) end |
#to_custom_created_at_lt ⇒ Object
133 134 135 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 133 def to_custom_created_at_lt DateTimeHelper.to_rfc3339(created_at_lt) end |
#to_custom_created_at_lte ⇒ Object
137 138 139 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 137 def to_custom_created_at_lte DateTimeHelper.to_rfc3339(created_at_lte) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
142 143 144 145 146 147 |
# File 'lib/api_reference/models/list_customers_query_params.rb', line 142 def to_s class_name = self.class.name.split('::').last "<#{class_name} limit: #{@limit}, cursor: #{@cursor}, created_at_gte: #{@created_at_gte},"\ " created_at_gt: #{@created_at_gt}, created_at_lt: #{@created_at_lt}, created_at_lte:"\ " #{@created_at_lte}>" end |