Class: ApiReference::MatrixWithDisplayNameConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/matrix_with_display_name_config.rb

Overview

Configuration for matrix with display name pricing

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(dimension:, unit_amounts:) ⇒ MatrixWithDisplayNameConfig

Returns a new instance of MatrixWithDisplayNameConfig.



38
39
40
41
# File 'lib/api_reference/models/matrix_with_display_name_config.rb', line 38

def initialize(dimension:, unit_amounts:)
  @dimension = dimension
  @unit_amounts = unit_amounts
end

Instance Attribute Details

#dimensionString

Used to determine the unit rate

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/matrix_with_display_name_config.rb', line 14

def dimension
  @dimension
end

#unit_amountsArray[MatrixWithDisplayNameUnitAmountItem]

Apply per unit pricing to each dimension value



18
19
20
# File 'lib/api_reference/models/matrix_with_display_name_config.rb', line 18

def unit_amounts
  @unit_amounts
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/api_reference/models/matrix_with_display_name_config.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  dimension = hash.key?('dimension') ? hash['dimension'] : nil
  # Parameter is an array, so we need to iterate through it
  unit_amounts = nil
  unless hash['unit_amounts'].nil?
    unit_amounts = []
    hash['unit_amounts'].each do |structure|
      unit_amounts << (MatrixWithDisplayNameUnitAmountItem.from_hash(structure) if structure)
    end
  end

  unit_amounts = nil unless hash.key?('unit_amounts')

  # Create object from extracted values.
  MatrixWithDisplayNameConfig.new(dimension: dimension,
                                  unit_amounts: unit_amounts)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/matrix_with_display_name_config.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['dimension'] = 'dimension'
  @_hash['unit_amounts'] = 'unit_amounts'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/api_reference/models/matrix_with_display_name_config.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/api_reference/models/matrix_with_display_name_config.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
# File 'lib/api_reference/models/matrix_with_display_name_config.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} dimension: #{@dimension.inspect}, unit_amounts: #{@unit_amounts.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



66
67
68
69
# File 'lib/api_reference/models/matrix_with_display_name_config.rb', line 66

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} dimension: #{@dimension}, unit_amounts: #{@unit_amounts}>"
end