Class: ApiReference::MatrixWithThresholdDiscountsConfig1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/matrix_with_threshold_discounts_config1.rb

Overview

Configuration for matrix_with_threshold_discounts pricing

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(first_dimension:, default_unit_amount:, matrix_values:, second_dimension: SKIP, threshold_discount_groups: SKIP) ⇒ MatrixWithThresholdDiscountsConfig1

Returns a new instance of MatrixWithThresholdDiscountsConfig1.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 58

def initialize(first_dimension:, default_unit_amount:, matrix_values:,
               second_dimension: SKIP, threshold_discount_groups: SKIP)
  @first_dimension = first_dimension
  @second_dimension = second_dimension unless second_dimension == SKIP
  @default_unit_amount = default_unit_amount
  @matrix_values = matrix_values
  unless threshold_discount_groups == SKIP
    @threshold_discount_groups =
      threshold_discount_groups
  end
end

Instance Attribute Details

#default_unit_amountString

Unit price used for usage that does not match any defined matrix cell.

Returns:

  • (String)


22
23
24
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 22

def default_unit_amount
  @default_unit_amount
end

#first_dimensionString

First matrix dimension key.

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 14

def first_dimension
  @first_dimension
end

#matrix_valuesArray[MatrixCell]

Per-cell unit prices.

Returns:



26
27
28
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 26

def matrix_values
  @matrix_values
end

#second_dimensionString

Optional second matrix dimension key.

Returns:

  • (String)


18
19
20
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 18

def second_dimension
  @second_dimension
end

#threshold_discount_groupsArray[ThresholdDiscountGroup]

Per-cell unit prices.

Returns:



30
31
32
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 30

def threshold_discount_groups
  @threshold_discount_groups
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 71

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  first_dimension =
    hash.key?('first_dimension') ? hash['first_dimension'] : nil
  default_unit_amount =
    hash.key?('default_unit_amount') ? hash['default_unit_amount'] : nil
  # Parameter is an array, so we need to iterate through it
  matrix_values = nil
  unless hash['matrix_values'].nil?
    matrix_values = []
    hash['matrix_values'].each do |structure|
      matrix_values << (MatrixCell.from_hash(structure) if structure)
    end
  end

  matrix_values = nil unless hash.key?('matrix_values')
  second_dimension =
    hash.key?('second_dimension') ? hash['second_dimension'] : SKIP
  # Parameter is an array, so we need to iterate through it
  threshold_discount_groups = nil
  unless hash['threshold_discount_groups'].nil?
    threshold_discount_groups = []
    hash['threshold_discount_groups'].each do |structure|
      threshold_discount_groups << (ThresholdDiscountGroup.from_hash(structure) if structure)
    end
  end

  threshold_discount_groups = SKIP unless hash.key?('threshold_discount_groups')

  # Create object from extracted values.
  MatrixWithThresholdDiscountsConfig1.new(first_dimension: first_dimension,
                                          default_unit_amount: default_unit_amount,
                                          matrix_values: matrix_values,
                                          second_dimension: second_dimension,
                                          threshold_discount_groups: threshold_discount_groups)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first_dimension'] = 'first_dimension'
  @_hash['second_dimension'] = 'second_dimension'
  @_hash['default_unit_amount'] = 'default_unit_amount'
  @_hash['matrix_values'] = 'matrix_values'
  @_hash['threshold_discount_groups'] = 'threshold_discount_groups'
  @_hash
end

.nullablesObject

An array for nullable fields



52
53
54
55
56
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 52

def self.nullables
  %w[
    second_dimension
  ]
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 44

def self.optionals
  %w[
    second_dimension
    threshold_discount_groups
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 112

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.first_dimension,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.default_unit_amount,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.matrix_values,
                              ->(val) { MatrixCell.validate(val) },
                              is_model_hash: true,
                              is_inner_model_hash: true)
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['first_dimension'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['default_unit_amount'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['matrix_values'],
                            ->(val) { MatrixCell.validate(val) },
                            is_model_hash: true,
                            is_inner_model_hash: true)
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



149
150
151
152
153
154
155
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 149

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first_dimension: #{@first_dimension.inspect}, second_dimension:"\
  " #{@second_dimension.inspect}, default_unit_amount: #{@default_unit_amount.inspect},"\
  " matrix_values: #{@matrix_values.inspect}, threshold_discount_groups:"\
  " #{@threshold_discount_groups.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



141
142
143
144
145
146
# File 'lib/api_reference/models/matrix_with_threshold_discounts_config1.rb', line 141

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first_dimension: #{@first_dimension}, second_dimension:"\
  " #{@second_dimension}, default_unit_amount: #{@default_unit_amount}, matrix_values:"\
  " #{@matrix_values}, threshold_discount_groups: #{@threshold_discount_groups}>"
end