Class: ApiReference::MetricApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/api_reference/apis/metric_api.rb

Overview

MetricApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from ApiReference::BaseApi

Instance Method Details

#create_metric(body) ⇒ ApiResponse

This endpoint is used to create a metric using a SQL string. See SQL support for a description of constructing SQL queries with examples. here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/api_reference/apis/metric_api.rb', line 76

def create_metric(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/metrics',
                                 Server::DEFAULT)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('APIKeyAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(BillableMetric.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             APIException)
                .local_error('401',
                             'Unauthorized',
                             AuthorizationErrorException)
                .local_error('404',
                             'Not Found',
                             APIException)
                .local_error('409',
                             'Conflict',
                             IdempotencyRequestMismatchException)
                .local_error('413',
                             'Content Too Large',
                             APIException)
                .local_error('429',
                             'Too Many Requests',
                             TooManyRequestsException)
                .local_error('500',
                             'Internal Server Error',
                             ServerErrorException))
    .execute
end

#fetch_metric(metric_id) ⇒ ApiResponse

This endpoint is used to fetch metric details given a metric identifier. It returns information about the metrics including its name, description, and item. here

Parameters:

  • metric_id (String)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/api_reference/apis/metric_api.rb', line 122

def fetch_metric(metric_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/metrics/{metric_id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(metric_id, key: 'metric_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('APIKeyAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(BillableMetric.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             APIException)
                .local_error('401',
                             'Unauthorized',
                             AuthorizationErrorException)
                .local_error('404',
                             'Not Found',
                             APIException)
                .local_error('409',
                             'Conflict',
                             IdempotencyRequestMismatchException)
                .local_error('413',
                             'Content Too Large',
                             APIException)
                .local_error('429',
                             'Too Many Requests',
                             TooManyRequestsException)
                .local_error('500',
                             'Internal Server Error',
                             ServerErrorException))
    .execute
end

#list_metrics(limit: 20, cursor: nil, created_at_gte: nil, created_at_gt: nil, created_at_lt: nil, created_at_lte: nil) ⇒ ApiResponse

This endpoint is used to list metrics. It returns information about the metrics including its name, description, and item. description here here here description here

Parameters:

  • limit (Integer) (defaults to: 20)

    Optional parameter: Example:20

  • cursor (String) (defaults to: nil)

    Optional parameter: TODO: type description here

  • created_at_gte (DateTime) (defaults to: nil)

    Optional parameter: TODO: type

  • created_at_gt (DateTime) (defaults to: nil)

    Optional parameter: TODO: type description

  • created_at_lt (DateTime) (defaults to: nil)

    Optional parameter: TODO: type description

  • created_at_lte (DateTime) (defaults to: nil)

    Optional parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/api_reference/apis/metric_api.rb', line 23

def list_metrics(limit: 20,
                 cursor: nil,
                 created_at_gte: nil,
                 created_at_gt: nil,
                 created_at_lt: nil,
                 created_at_lte: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/metrics',
                                 Server::DEFAULT)
               .query_param(new_parameter(limit, key: 'limit'))
               .query_param(new_parameter(cursor, key: 'cursor'))
               .query_param(new_parameter(created_at_gte, key: 'created_at[gte]'))
               .query_param(new_parameter(created_at_gt, key: 'created_at[gt]'))
               .query_param(new_parameter(created_at_lt, key: 'created_at[lt]'))
               .query_param(new_parameter(created_at_lte, key: 'created_at[lte]'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('APIKeyAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(BillableMetrics.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             APIException)
                .local_error('401',
                             'Unauthorized',
                             AuthorizationErrorException)
                .local_error('404',
                             'Not Found',
                             APIException)
                .local_error('409',
                             'Conflict',
                             IdempotencyRequestMismatchException)
                .local_error('413',
                             'Content Too Large',
                             APIException)
                .local_error('429',
                             'Too Many Requests',
                             TooManyRequestsException)
                .local_error('500',
                             'Internal Server Error',
                             ServerErrorException))
    .execute
end

#update_metric(metric_id, body) ⇒ ApiResponse

This endpoint allows you to update the metadata property on a metric. If you pass null for the metadata value, it will clear any existing metadata for that invoice. here description here

Parameters:

  • metric_id (String)

    Required parameter: TODO: type description

  • body (UpdateMetricRequestParams)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/api_reference/apis/metric_api.rb', line 168

def update_metric(metric_id,
                  body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/metrics/{metric_id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(metric_id, key: 'metric_id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('APIKeyAuth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(BillableMetric.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             APIException)
                .local_error('401',
                             'Unauthorized',
                             AuthorizationErrorException)
                .local_error('404',
                             'Not Found',
                             APIException)
                .local_error('409',
                             'Conflict',
                             IdempotencyRequestMismatchException)
                .local_error('413',
                             'Content Too Large',
                             APIException)
                .local_error('429',
                             'Too Many Requests',
                             TooManyRequestsException)
                .local_error('500',
                             'Internal Server Error',
                             ServerErrorException))
    .execute
end