Class: ApiReference::NewCouponPercentageDiscount

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/new_coupon_percentage_discount.rb

Overview

NewCouponPercentageDiscount Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(percentage_discount:, additional_properties: nil) ⇒ NewCouponPercentageDiscount

Returns a new instance of NewCouponPercentageDiscount.



38
39
40
41
42
43
44
45
# File 'lib/api_reference/models/new_coupon_percentage_discount.rb', line 38

def initialize(percentage_discount:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @discount_type = 'percentage'
  @percentage_discount = percentage_discount
  @additional_properties = additional_properties
end

Instance Attribute Details

#discount_typeString (readonly)

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/new_coupon_percentage_discount.rb', line 14

def discount_type
  @discount_type
end

#percentage_discountFloat

TODO: Write general description for this method

Returns:

  • (Float)


18
19
20
# File 'lib/api_reference/models/new_coupon_percentage_discount.rb', line 18

def percentage_discount
  @percentage_discount
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/api_reference/models/new_coupon_percentage_discount.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  percentage_discount =
    hash.key?('percentage_discount') ? hash['percentage_discount'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  NewCouponPercentageDiscount.new(percentage_discount: percentage_discount,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/new_coupon_percentage_discount.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['discount_type'] = 'discount_type'
  @_hash['percentage_discount'] = 'percentage_discount'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/api_reference/models/new_coupon_percentage_discount.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/api_reference/models/new_coupon_percentage_discount.rb', line 29

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/api_reference/models/new_coupon_percentage_discount.rb', line 69

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.discount_type,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.percentage_discount,
                              ->(val) { val.instance_of? Float })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['discount_type'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['percentage_discount'],
                            ->(val) { val.instance_of? Float })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



97
98
99
100
101
# File 'lib/api_reference/models/new_coupon_percentage_discount.rb', line 97

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} discount_type: #{@discount_type.inspect}, percentage_discount:"\
  " #{@percentage_discount.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



90
91
92
93
94
# File 'lib/api_reference/models/new_coupon_percentage_discount.rb', line 90

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} discount_type: #{@discount_type}, percentage_discount:"\
  " #{@percentage_discount}, additional_properties: #{@additional_properties}>"
end