Class: ApiReference::NewCustomerBalanceTransaction

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/new_customer_balance_transaction.rb

Overview

NewCustomerBalanceTransaction Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount:, type:, description: SKIP) ⇒ NewCustomerBalanceTransaction

Returns a new instance of NewCustomerBalanceTransaction.



47
48
49
50
51
# File 'lib/api_reference/models/new_customer_balance_transaction.rb', line 47

def initialize(amount:, type:, description: SKIP)
  @amount = amount
  @type = type
  @description = description unless description == SKIP
end

Instance Attribute Details

#amountString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/new_customer_balance_transaction.rb', line 14

def amount
  @amount
end

#descriptionString

An optional description that can be specified around this entry.

Returns:

  • (String)


22
23
24
# File 'lib/api_reference/models/new_customer_balance_transaction.rb', line 22

def description
  @description
end

#typeType4

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/api_reference/models/new_customer_balance_transaction.rb', line 18

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/api_reference/models/new_customer_balance_transaction.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount = hash.key?('amount') ? hash['amount'] : nil
  type = hash.key?('type') ? hash['type'] : nil
  description = hash.key?('description') ? hash['description'] : SKIP

  # Create object from extracted values.
  NewCustomerBalanceTransaction.new(amount: amount,
                                    type: type,
                                    description: description)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/api_reference/models/new_customer_balance_transaction.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount'] = 'amount'
  @_hash['type'] = 'type'
  @_hash['description'] = 'description'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
44
45
# File 'lib/api_reference/models/new_customer_balance_transaction.rb', line 41

def self.nullables
  %w[
    description
  ]
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/api_reference/models/new_customer_balance_transaction.rb', line 34

def self.optionals
  %w[
    description
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
79
# File 'lib/api_reference/models/new_customer_balance_transaction.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount.inspect}, type: #{@type.inspect}, description:"\
  " #{@description.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/api_reference/models/new_customer_balance_transaction.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount}, type: #{@type}, description: #{@description}>"
end