Class: ApiReference::NewLicenseAllocation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/new_license_allocation.rb

Overview

NewLicenseAllocation Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(currency:, amount:, write_off_overage: SKIP, additional_properties: nil) ⇒ NewLicenseAllocation

Returns a new instance of NewLicenseAllocation.



47
48
49
50
51
52
53
54
55
56
# File 'lib/api_reference/models/new_license_allocation.rb', line 47

def initialize(currency:, amount:, write_off_overage: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @currency = currency
  @amount = amount
  @write_off_overage = write_off_overage unless write_off_overage == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountString

The amount of credits granted per active license per cadence.

Returns:

  • (String)


18
19
20
# File 'lib/api_reference/models/new_license_allocation.rb', line 18

def amount
  @amount
end

#currencyString

The currency of the license allocation.

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/new_license_allocation.rb', line 14

def currency
  @currency
end

#write_off_overageTrueClass | FalseClass

When True, overage beyond the allocation is written off.

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/api_reference/models/new_license_allocation.rb', line 22

def write_off_overage
  @write_off_overage
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/api_reference/models/new_license_allocation.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  currency = hash.key?('currency') ? hash['currency'] : nil
  amount = hash.key?('amount') ? hash['amount'] : nil
  write_off_overage =
    hash.key?('write_off_overage') ? hash['write_off_overage'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  NewLicenseAllocation.new(currency: currency,
                           amount: amount,
                           write_off_overage: write_off_overage,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/api_reference/models/new_license_allocation.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['currency'] = 'currency'
  @_hash['amount'] = 'amount'
  @_hash['write_off_overage'] = 'write_off_overage'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
44
45
# File 'lib/api_reference/models/new_license_allocation.rb', line 41

def self.nullables
  %w[
    write_off_overage
  ]
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/api_reference/models/new_license_allocation.rb', line 34

def self.optionals
  %w[
    write_off_overage
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
95
# File 'lib/api_reference/models/new_license_allocation.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency.inspect}, amount: #{@amount.inspect},"\
  " write_off_overage: #{@write_off_overage.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/api_reference/models/new_license_allocation.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency}, amount: #{@amount}, write_off_overage:"\
  " #{@write_off_overage}, additional_properties: #{@additional_properties}>"
end