Class: ApiReference::NewLicenseType
- Defined in:
- lib/api_reference/models/new_license_type.rb
Overview
NewLicenseType Model.
Instance Attribute Summary collapse
-
#grouping_key ⇒ String
The key used for grouping licenses of this type.
-
#name ⇒ String
The name of the license type.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, grouping_key:) ⇒ NewLicenseType
constructor
A new instance of NewLicenseType.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, grouping_key:) ⇒ NewLicenseType
Returns a new instance of NewLicenseType.
39 40 41 42 |
# File 'lib/api_reference/models/new_license_type.rb', line 39 def initialize(name:, grouping_key:) @name = name @grouping_key = grouping_key end |
Instance Attribute Details
#grouping_key ⇒ String
The key used for grouping licenses of this type. This is typically a user identifier field.
19 20 21 |
# File 'lib/api_reference/models/new_license_type.rb', line 19 def grouping_key @grouping_key end |
#name ⇒ String
The name of the license type.
14 15 16 |
# File 'lib/api_reference/models/new_license_type.rb', line 14 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/api_reference/models/new_license_type.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil grouping_key = hash.key?('grouping_key') ? hash['grouping_key'] : nil # Create object from extracted values. NewLicenseType.new(name: name, grouping_key: grouping_key) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/api_reference/models/new_license_type.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['grouping_key'] = 'grouping_key' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/api_reference/models/new_license_type.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/api_reference/models/new_license_type.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 |
# File 'lib/api_reference/models/new_license_type.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, grouping_key: #{@grouping_key.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/api_reference/models/new_license_type.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, grouping_key: #{@grouping_key}>" end |