Class: ApiReference::PaginationMetadata

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/pagination_metadata.rb

Overview

PaginationMetadata Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(has_more:, next_cursor:, additional_properties: nil) ⇒ PaginationMetadata

Returns a new instance of PaginationMetadata.



40
41
42
43
44
45
46
47
# File 'lib/api_reference/models/pagination_metadata.rb', line 40

def initialize(has_more:, next_cursor:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @has_more = has_more
  @next_cursor = next_cursor
  @additional_properties = additional_properties
end

Instance Attribute Details

#has_moreTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/api_reference/models/pagination_metadata.rb', line 14

def has_more
  @has_more
end

#next_cursorString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/api_reference/models/pagination_metadata.rb', line 18

def next_cursor
  @next_cursor
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/api_reference/models/pagination_metadata.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  has_more = hash.key?('has_more') ? hash['has_more'] : nil
  next_cursor = hash.key?('next_cursor') ? hash['next_cursor'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaginationMetadata.new(has_more: has_more,
                         next_cursor: next_cursor,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/pagination_metadata.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['has_more'] = 'has_more'
  @_hash['next_cursor'] = 'next_cursor'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
37
38
# File 'lib/api_reference/models/pagination_metadata.rb', line 34

def self.nullables
  %w[
    next_cursor
  ]
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/api_reference/models/pagination_metadata.rb', line 29

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/api_reference/models/pagination_metadata.rb', line 72

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.has_more,
                            ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
        APIHelper.valid_type?(value.next_cursor,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['has_more'],
                          ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
      APIHelper.valid_type?(value['next_cursor'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



100
101
102
103
104
# File 'lib/api_reference/models/pagination_metadata.rb', line 100

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} has_more: #{@has_more.inspect}, next_cursor: #{@next_cursor.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
97
# File 'lib/api_reference/models/pagination_metadata.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} has_more: #{@has_more}, next_cursor: #{@next_cursor},"\
  " additional_properties: #{@additional_properties}>"
end