Class: ApiReference::PayInvoiceParams
- Defined in:
- lib/api_reference/models/pay_invoice_params.rb
Overview
PayInvoiceParams Model.
Instance Attribute Summary collapse
-
#shared_payment_token_id ⇒ String
The ID of a shared payment token granted by an agent to use for this payment.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(shared_payment_token_id:) ⇒ PayInvoiceParams
constructor
A new instance of PayInvoiceParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(shared_payment_token_id:) ⇒ PayInvoiceParams
Returns a new instance of PayInvoiceParams.
34 35 36 |
# File 'lib/api_reference/models/pay_invoice_params.rb', line 34 def initialize(shared_payment_token_id:) @shared_payment_token_id = shared_payment_token_id end |
Instance Attribute Details
#shared_payment_token_id ⇒ String
The ID of a shared payment token granted by an agent to use for this payment.
15 16 17 |
# File 'lib/api_reference/models/pay_invoice_params.rb', line 15 def shared_payment_token_id @shared_payment_token_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/api_reference/models/pay_invoice_params.rb', line 39 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. shared_payment_token_id = hash.key?('shared_payment_token_id') ? hash['shared_payment_token_id'] : nil # Create object from extracted values. PayInvoiceParams.new(shared_payment_token_id: shared_payment_token_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/api_reference/models/pay_invoice_params.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['shared_payment_token_id'] = 'shared_payment_token_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
30 31 32 |
# File 'lib/api_reference/models/pay_invoice_params.rb', line 30 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 |
# File 'lib/api_reference/models/pay_invoice_params.rb', line 25 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
57 58 59 60 |
# File 'lib/api_reference/models/pay_invoice_params.rb', line 57 def inspect class_name = self.class.name.split('::').last "<#{class_name} shared_payment_token_id: #{@shared_payment_token_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
51 52 53 54 |
# File 'lib/api_reference/models/pay_invoice_params.rb', line 51 def to_s class_name = self.class.name.split('::').last "<#{class_name} shared_payment_token_id: #{@shared_payment_token_id}>" end |