Class: ApiReference::PaymentConfiguration
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::PaymentConfiguration
- Defined in:
- lib/api_reference/models/payment_configuration.rb
Overview
PaymentConfiguration Model.
Instance Attribute Summary collapse
-
#payment_providers ⇒ Array[PaymentConfigurationItem]
Provider-specific payment configuration.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(payment_providers: SKIP, additional_properties: nil) ⇒ PaymentConfiguration
constructor
A new instance of PaymentConfiguration.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_providers: SKIP, additional_properties: nil) ⇒ PaymentConfiguration
Returns a new instance of PaymentConfiguration.
35 36 37 38 39 40 41 |
# File 'lib/api_reference/models/payment_configuration.rb', line 35 def initialize(payment_providers: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @payment_providers = payment_providers unless payment_providers == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#payment_providers ⇒ Array[PaymentConfigurationItem]
Provider-specific payment configuration.
14 15 16 |
# File 'lib/api_reference/models/payment_configuration.rb', line 14 def payment_providers @payment_providers end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/api_reference/models/payment_configuration.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it payment_providers = nil unless hash['payment_providers'].nil? payment_providers = [] hash['payment_providers'].each do |structure| payment_providers << (PaymentConfigurationItem.from_hash(structure) if structure) end end payment_providers = SKIP unless hash.key?('payment_providers') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentConfiguration.new(payment_providers: payment_providers, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/api_reference/models/payment_configuration.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['payment_providers'] = 'payment_providers' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/api_reference/models/payment_configuration.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/api_reference/models/payment_configuration.rb', line 24 def self.optionals %w[ payment_providers ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
73 74 75 76 77 78 79 |
# File 'lib/api_reference/models/payment_configuration.rb', line 73 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/api_reference/models/payment_configuration.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment_providers: #{@payment_providers.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/api_reference/models/payment_configuration.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment_providers: #{@payment_providers}, additional_properties:"\ " #{@additional_properties}>" end |