Class: ApiReference::PercentageDiscountCreationParams
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::PercentageDiscountCreationParams
- Defined in:
- lib/api_reference/models/percentage_discount_creation_params.rb
Overview
PercentageDiscountCreationParams Model.
Instance Attribute Summary collapse
-
#discount_type ⇒ String
readonly
TODO: Write general description for this method.
-
#percentage_discount ⇒ Float
Only available if discount_type is
percentage.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(percentage_discount:, additional_properties: nil) ⇒ PercentageDiscountCreationParams
constructor
A new instance of PercentageDiscountCreationParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(percentage_discount:, additional_properties: nil) ⇒ PercentageDiscountCreationParams
Returns a new instance of PercentageDiscountCreationParams.
39 40 41 42 43 44 45 46 |
# File 'lib/api_reference/models/percentage_discount_creation_params.rb', line 39 def initialize(percentage_discount:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @discount_type = 'percentage' @percentage_discount = percentage_discount @additional_properties = additional_properties end |
Instance Attribute Details
#discount_type ⇒ String (readonly)
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/percentage_discount_creation_params.rb', line 14 def discount_type @discount_type end |
#percentage_discount ⇒ Float
Only available if discount_type is percentage. This is a number between
0 and 1.
19 20 21 |
# File 'lib/api_reference/models/percentage_discount_creation_params.rb', line 19 def percentage_discount @percentage_discount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/api_reference/models/percentage_discount_creation_params.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. percentage_discount = hash.key?('percentage_discount') ? hash['percentage_discount'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PercentageDiscountCreationParams.new(percentage_discount: percentage_discount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/api_reference/models/percentage_discount_creation_params.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['discount_type'] = 'discount_type' @_hash['percentage_discount'] = 'percentage_discount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/api_reference/models/percentage_discount_creation_params.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/api_reference/models/percentage_discount_creation_params.rb', line 30 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/api_reference/models/percentage_discount_creation_params.rb', line 70 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.discount_type, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.percentage_discount, ->(val) { val.instance_of? Float }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['discount_type'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['percentage_discount'], ->(val) { val.instance_of? Float }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/api_reference/models/percentage_discount_creation_params.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} discount_type: #{@discount_type.inspect}, percentage_discount:"\ " #{@percentage_discount.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/api_reference/models/percentage_discount_creation_params.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} discount_type: #{@discount_type}, percentage_discount:"\ " #{@percentage_discount}, additional_properties: #{@additional_properties}>" end |