Class: ApiReference::RemovePlanAdjustmentParams

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/remove_plan_adjustment_params.rb

Overview

RemovePlanAdjustmentParams Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(adjustment_id:, plan_phase_order: SKIP) ⇒ RemovePlanAdjustmentParams

Returns a new instance of RemovePlanAdjustmentParams.



42
43
44
45
# File 'lib/api_reference/models/remove_plan_adjustment_params.rb', line 42

def initialize(adjustment_id:, plan_phase_order: SKIP)
  @adjustment_id = adjustment_id
  @plan_phase_order = plan_phase_order unless plan_phase_order == SKIP
end

Instance Attribute Details

#adjustment_idString

The id of the adjustment to remove from on the plan.

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/remove_plan_adjustment_params.rb', line 14

def adjustment_id
  @adjustment_id
end

#plan_phase_orderInteger

The phase to remove this adjustment from.

Returns:

  • (Integer)


18
19
20
# File 'lib/api_reference/models/remove_plan_adjustment_params.rb', line 18

def plan_phase_order
  @plan_phase_order
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/api_reference/models/remove_plan_adjustment_params.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  adjustment_id = hash.key?('adjustment_id') ? hash['adjustment_id'] : nil
  plan_phase_order =
    hash.key?('plan_phase_order') ? hash['plan_phase_order'] : SKIP

  # Create object from extracted values.
  RemovePlanAdjustmentParams.new(adjustment_id: adjustment_id,
                                 plan_phase_order: plan_phase_order)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/remove_plan_adjustment_params.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['adjustment_id'] = 'adjustment_id'
  @_hash['plan_phase_order'] = 'plan_phase_order'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
39
40
# File 'lib/api_reference/models/remove_plan_adjustment_params.rb', line 36

def self.nullables
  %w[
    plan_phase_order
  ]
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/api_reference/models/remove_plan_adjustment_params.rb', line 29

def self.optionals
  %w[
    plan_phase_order
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



68
69
70
71
72
# File 'lib/api_reference/models/remove_plan_adjustment_params.rb', line 68

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} adjustment_id: #{@adjustment_id.inspect}, plan_phase_order:"\
  " #{@plan_phase_order.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



62
63
64
65
# File 'lib/api_reference/models/remove_plan_adjustment_params.rb', line 62

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} adjustment_id: #{@adjustment_id}, plan_phase_order: #{@plan_phase_order}>"
end