Class: ApiReference::RemovePlanPriceParams

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/remove_plan_price_params.rb

Overview

RemovePlanPriceParams Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(price_id:, plan_phase_order: SKIP) ⇒ RemovePlanPriceParams

Returns a new instance of RemovePlanPriceParams.



42
43
44
45
# File 'lib/api_reference/models/remove_plan_price_params.rb', line 42

def initialize(price_id:, plan_phase_order: SKIP)
  @price_id = price_id
  @plan_phase_order = plan_phase_order unless plan_phase_order == SKIP
end

Instance Attribute Details

#plan_phase_orderInteger

The phase to remove this price from.

Returns:

  • (Integer)


18
19
20
# File 'lib/api_reference/models/remove_plan_price_params.rb', line 18

def plan_phase_order
  @plan_phase_order
end

#price_idString

The id of the price to remove from the plan.

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/remove_plan_price_params.rb', line 14

def price_id
  @price_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/api_reference/models/remove_plan_price_params.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  price_id = hash.key?('price_id') ? hash['price_id'] : nil
  plan_phase_order =
    hash.key?('plan_phase_order') ? hash['plan_phase_order'] : SKIP

  # Create object from extracted values.
  RemovePlanPriceParams.new(price_id: price_id,
                            plan_phase_order: plan_phase_order)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/remove_plan_price_params.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['price_id'] = 'price_id'
  @_hash['plan_phase_order'] = 'plan_phase_order'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
39
40
# File 'lib/api_reference/models/remove_plan_price_params.rb', line 36

def self.nullables
  %w[
    plan_phase_order
  ]
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/api_reference/models/remove_plan_price_params.rb', line 29

def self.optionals
  %w[
    plan_phase_order
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



68
69
70
71
72
# File 'lib/api_reference/models/remove_plan_price_params.rb', line 68

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} price_id: #{@price_id.inspect}, plan_phase_order:"\
  " #{@plan_phase_order.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



62
63
64
65
# File 'lib/api_reference/models/remove_plan_price_params.rb', line 62

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} price_id: #{@price_id}, plan_phase_order: #{@plan_phase_order}>"
end