Class: ApiReference::ReplacePlanAdjustmentParams

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/replace_plan_adjustment_params.rb

Overview

ReplacePlanAdjustmentParams Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(adjustment:, replaces_adjustment_id:, plan_phase_order: SKIP) ⇒ ReplacePlanAdjustmentParams

Returns a new instance of ReplacePlanAdjustmentParams.



47
48
49
50
51
# File 'lib/api_reference/models/replace_plan_adjustment_params.rb', line 47

def initialize(adjustment:, replaces_adjustment_id:, plan_phase_order: SKIP)
  @adjustment = adjustment
  @replaces_adjustment_id = replaces_adjustment_id
  @plan_phase_order = plan_phase_order unless plan_phase_order == SKIP
end

Instance Attribute Details

#adjustmentObject

The definition of a new adjustment to create and add to the plan.

Returns:

  • (Object)


14
15
16
# File 'lib/api_reference/models/replace_plan_adjustment_params.rb', line 14

def adjustment
  @adjustment
end

#plan_phase_orderInteger

The phase to replace this adjustment from.

Returns:

  • (Integer)


22
23
24
# File 'lib/api_reference/models/replace_plan_adjustment_params.rb', line 22

def plan_phase_order
  @plan_phase_order
end

#replaces_adjustment_idString

The id of the adjustment on the plan to replace in the plan.

Returns:

  • (String)


18
19
20
# File 'lib/api_reference/models/replace_plan_adjustment_params.rb', line 18

def replaces_adjustment_id
  @replaces_adjustment_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/api_reference/models/replace_plan_adjustment_params.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  adjustment = hash.key?('adjustment') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:ReplacePlanAdjustmentParamsAdjustment), hash['adjustment']
  ) : nil
  replaces_adjustment_id =
    hash.key?('replaces_adjustment_id') ? hash['replaces_adjustment_id'] : nil
  plan_phase_order =
    hash.key?('plan_phase_order') ? hash['plan_phase_order'] : SKIP

  # Create object from extracted values.
  ReplacePlanAdjustmentParams.new(adjustment: adjustment,
                                  replaces_adjustment_id: replaces_adjustment_id,
                                  plan_phase_order: plan_phase_order)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/api_reference/models/replace_plan_adjustment_params.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['adjustment'] = 'adjustment'
  @_hash['replaces_adjustment_id'] = 'replaces_adjustment_id'
  @_hash['plan_phase_order'] = 'plan_phase_order'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
44
45
# File 'lib/api_reference/models/replace_plan_adjustment_params.rb', line 41

def self.nullables
  %w[
    plan_phase_order
  ]
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/api_reference/models/replace_plan_adjustment_params.rb', line 34

def self.optionals
  %w[
    plan_phase_order
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/api_reference/models/replace_plan_adjustment_params.rb', line 74

def self.validate(value)
  if value.instance_of? self
    return (
      UnionTypeLookUp.get(:ReplacePlanAdjustmentParamsAdjustment)
                     .validate(value.adjustment) and
        APIHelper.valid_type?(value.replaces_adjustment_id,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    UnionTypeLookUp.get(:ReplacePlanAdjustmentParamsAdjustment)
                   .validate(value['adjustment']) and
      APIHelper.valid_type?(value['replaces_adjustment_id'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
# File 'lib/api_reference/models/replace_plan_adjustment_params.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} adjustment: #{@adjustment.inspect}, replaces_adjustment_id:"\
  " #{@replaces_adjustment_id.inspect}, plan_phase_order: #{@plan_phase_order.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
# File 'lib/api_reference/models/replace_plan_adjustment_params.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} adjustment: #{@adjustment}, replaces_adjustment_id:"\
  " #{@replaces_adjustment_id}, plan_phase_order: #{@plan_phase_order}>"
end