Class: ApiReference::SubLineItemGrouping

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/sub_line_item_grouping.rb

Overview

SubLineItemGrouping Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(key:, value:, additional_properties: nil) ⇒ SubLineItemGrouping

Returns a new instance of SubLineItemGrouping.



40
41
42
43
44
45
46
47
# File 'lib/api_reference/models/sub_line_item_grouping.rb', line 40

def initialize(key:, value:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @key = key
  @value = value
  @additional_properties = additional_properties
end

Instance Attribute Details

#keyString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/sub_line_item_grouping.rb', line 14

def key
  @key
end

#valueString

No value indicates the default group

Returns:

  • (String)


18
19
20
# File 'lib/api_reference/models/sub_line_item_grouping.rb', line 18

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/api_reference/models/sub_line_item_grouping.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  key = hash.key?('key') ? hash['key'] : nil
  value = hash.key?('value') ? hash['value'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SubLineItemGrouping.new(key: key,
                          value: value,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/sub_line_item_grouping.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['key'] = 'key'
  @_hash['value'] = 'value'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
37
38
# File 'lib/api_reference/models/sub_line_item_grouping.rb', line 34

def self.nullables
  %w[
    value
  ]
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/api_reference/models/sub_line_item_grouping.rb', line 29

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/api_reference/models/sub_line_item_grouping.rb', line 72

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.key,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.value,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['key'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['value'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



100
101
102
103
104
# File 'lib/api_reference/models/sub_line_item_grouping.rb', line 100

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key.inspect}, value: #{@value.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
97
# File 'lib/api_reference/models/sub_line_item_grouping.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key}, value: #{@value}, additional_properties:"\
  " #{@additional_properties}>"
end