Class: ApiReference::TierSubLineItemTierConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::TierSubLineItemTierConfig
- Defined in:
- lib/api_reference/models/tier_sub_line_item_tier_config.rb
Overview
TierSubLineItemTierConfig Model.
Instance Attribute Summary collapse
-
#first_unit ⇒ Float
TODO: Write general description for this method.
-
#last_unit ⇒ Float
TODO: Write general description for this method.
-
#unit_amount ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(first_unit:, last_unit:, unit_amount:, additional_properties: nil) ⇒ TierSubLineItemTierConfig
constructor
A new instance of TierSubLineItemTierConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(first_unit:, last_unit:, unit_amount:, additional_properties: nil) ⇒ TierSubLineItemTierConfig
Returns a new instance of TierSubLineItemTierConfig.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/api_reference/models/tier_sub_line_item_tier_config.rb', line 45 def initialize(first_unit:, last_unit:, unit_amount:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @first_unit = first_unit @last_unit = last_unit @unit_amount = unit_amount @additional_properties = additional_properties end |
Instance Attribute Details
#first_unit ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/tier_sub_line_item_tier_config.rb', line 14 def first_unit @first_unit end |
#last_unit ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/api_reference/models/tier_sub_line_item_tier_config.rb', line 18 def last_unit @last_unit end |
#unit_amount ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/api_reference/models/tier_sub_line_item_tier_config.rb', line 22 def unit_amount @unit_amount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/api_reference/models/tier_sub_line_item_tier_config.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. first_unit = hash.key?('first_unit') ? hash['first_unit'] : nil last_unit = hash.key?('last_unit') ? hash['last_unit'] : nil unit_amount = hash.key?('unit_amount') ? hash['unit_amount'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TierSubLineItemTierConfig.new(first_unit: first_unit, last_unit: last_unit, unit_amount: unit_amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/api_reference/models/tier_sub_line_item_tier_config.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['first_unit'] = 'first_unit' @_hash['last_unit'] = 'last_unit' @_hash['unit_amount'] = 'unit_amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 42 43 |
# File 'lib/api_reference/models/tier_sub_line_item_tier_config.rb', line 39 def self.nullables %w[ last_unit ] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/api_reference/models/tier_sub_line_item_tier_config.rb', line 34 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/api_reference/models/tier_sub_line_item_tier_config.rb', line 81 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.first_unit, ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value.last_unit, ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value.unit_amount, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['first_unit'], ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value['last_unit'], ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value['unit_amount'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
113 114 115 116 117 |
# File 'lib/api_reference/models/tier_sub_line_item_tier_config.rb', line 113 def inspect class_name = self.class.name.split('::').last "<#{class_name} first_unit: #{@first_unit.inspect}, last_unit: #{@last_unit.inspect},"\ " unit_amount: #{@unit_amount.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 |
# File 'lib/api_reference/models/tier_sub_line_item_tier_config.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} first_unit: #{@first_unit}, last_unit: #{@last_unit}, unit_amount:"\ " #{@unit_amount}, additional_properties: #{@additional_properties}>" end |