Class: ApiReference::TieredPricingWithMinimumTierItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::TieredPricingWithMinimumTierItem
- Defined in:
- lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb
Overview
Configuration for a single tier
Instance Attribute Summary collapse
-
#minimum_amount ⇒ String
Per unit amount.
-
#tier_lower_bound ⇒ String
TODO: Write general description for this method.
-
#unit_amount ⇒ String
Per unit amount.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(tier_lower_bound:, unit_amount:, minimum_amount:) ⇒ TieredPricingWithMinimumTierItem
constructor
A new instance of TieredPricingWithMinimumTierItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tier_lower_bound:, unit_amount:, minimum_amount:) ⇒ TieredPricingWithMinimumTierItem
Returns a new instance of TieredPricingWithMinimumTierItem.
43 44 45 46 47 |
# File 'lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb', line 43 def initialize(tier_lower_bound:, unit_amount:, minimum_amount:) @tier_lower_bound = tier_lower_bound @unit_amount = unit_amount @minimum_amount = minimum_amount end |
Instance Attribute Details
#minimum_amount ⇒ String
Per unit amount
22 23 24 |
# File 'lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb', line 22 def minimum_amount @minimum_amount end |
#tier_lower_bound ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb', line 14 def tier_lower_bound @tier_lower_bound end |
#unit_amount ⇒ String
Per unit amount
18 19 20 |
# File 'lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb', line 18 def unit_amount @unit_amount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tier_lower_bound = hash.key?('tier_lower_bound') ? hash['tier_lower_bound'] : nil unit_amount = hash.key?('unit_amount') ? hash['unit_amount'] : nil minimum_amount = hash.key?('minimum_amount') ? hash['minimum_amount'] : nil # Create object from extracted values. TieredPricingWithMinimumTierItem.new(tier_lower_bound: tier_lower_bound, unit_amount: unit_amount, minimum_amount: minimum_amount) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['tier_lower_bound'] = 'tier_lower_bound' @_hash['unit_amount'] = 'unit_amount' @_hash['minimum_amount'] = 'minimum_amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb', line 34 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb', line 68 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.tier_lower_bound, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.unit_amount, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.minimum_amount, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['tier_lower_bound'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['unit_amount'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['minimum_amount'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 |
# File 'lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} tier_lower_bound: #{@tier_lower_bound.inspect}, unit_amount:"\ " #{@unit_amount.inspect}, minimum_amount: #{@minimum_amount.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 |
# File 'lib/api_reference/models/tiered_pricing_with_minimum_tier_item.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} tier_lower_bound: #{@tier_lower_bound}, unit_amount: #{@unit_amount},"\ " minimum_amount: #{@minimum_amount}>" end |