Class: ApiReference::TieredWithProrationTier

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/tiered_with_proration_tier.rb

Overview

Configuration for a single tiered with proration tier

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tier_lower_bound:, unit_amount:) ⇒ TieredWithProrationTier

Returns a new instance of TieredWithProrationTier.



38
39
40
41
# File 'lib/api_reference/models/tiered_with_proration_tier.rb', line 38

def initialize(tier_lower_bound:, unit_amount:)
  @tier_lower_bound = tier_lower_bound
  @unit_amount = unit_amount
end

Instance Attribute Details

#tier_lower_boundString

Inclusive tier starting value

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/tiered_with_proration_tier.rb', line 14

def tier_lower_bound
  @tier_lower_bound
end

#unit_amountString

Amount per unit

Returns:

  • (String)


18
19
20
# File 'lib/api_reference/models/tiered_with_proration_tier.rb', line 18

def unit_amount
  @unit_amount
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/api_reference/models/tiered_with_proration_tier.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tier_lower_bound =
    hash.key?('tier_lower_bound') ? hash['tier_lower_bound'] : nil
  unit_amount = hash.key?('unit_amount') ? hash['unit_amount'] : nil

  # Create object from extracted values.
  TieredWithProrationTier.new(tier_lower_bound: tier_lower_bound,
                              unit_amount: unit_amount)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/tiered_with_proration_tier.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tier_lower_bound'] = 'tier_lower_bound'
  @_hash['unit_amount'] = 'unit_amount'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/api_reference/models/tiered_with_proration_tier.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/api_reference/models/tiered_with_proration_tier.rb', line 29

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/api_reference/models/tiered_with_proration_tier.rb', line 59

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.tier_lower_bound,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.unit_amount,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['tier_lower_bound'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['unit_amount'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/api_reference/models/tiered_with_proration_tier.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tier_lower_bound: #{@tier_lower_bound.inspect}, unit_amount:"\
  " #{@unit_amount.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
# File 'lib/api_reference/models/tiered_with_proration_tier.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tier_lower_bound: #{@tier_lower_bound}, unit_amount: #{@unit_amount}>"
end