Class: ApiReference::TrialConfig
- Defined in:
- lib/api_reference/models/trial_config.rb
Overview
TrialConfig Model.
Instance Attribute Summary collapse
-
#trial_period ⇒ Integer
TODO: Write general description for this method.
-
#trial_period_unit ⇒ String
readonly
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(trial_period:, additional_properties: nil) ⇒ TrialConfig
constructor
A new instance of TrialConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(trial_period:, additional_properties: nil) ⇒ TrialConfig
Returns a new instance of TrialConfig.
40 41 42 43 44 45 46 47 |
# File 'lib/api_reference/models/trial_config.rb', line 40 def initialize(trial_period:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @trial_period = trial_period @trial_period_unit = 'days' @additional_properties = additional_properties end |
Instance Attribute Details
#trial_period ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/trial_config.rb', line 14 def trial_period @trial_period end |
#trial_period_unit ⇒ String (readonly)
TODO: Write general description for this method
18 19 20 |
# File 'lib/api_reference/models/trial_config.rb', line 18 def trial_period_unit @trial_period_unit end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/api_reference/models/trial_config.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. trial_period = hash.key?('trial_period') ? hash['trial_period'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TrialConfig.new(trial_period: trial_period, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/api_reference/models/trial_config.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['trial_period'] = 'trial_period' @_hash['trial_period_unit'] = 'trial_period_unit' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 37 38 |
# File 'lib/api_reference/models/trial_config.rb', line 34 def self.nullables %w[ trial_period ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/api_reference/models/trial_config.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/api_reference/models/trial_config.rb', line 70 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.trial_period, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.trial_period_unit, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['trial_period'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['trial_period_unit'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/api_reference/models/trial_config.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} trial_period: #{@trial_period.inspect}, trial_period_unit:"\ " #{@trial_period_unit.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/api_reference/models/trial_config.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} trial_period: #{@trial_period}, trial_period_unit: #{@trial_period_unit},"\ " additional_properties: #{@additional_properties}>" end |