Class: ApiReference::UnitWithPercentConfig1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/api_reference/models/unit_with_percent_config1.rb

Overview

Configuration for unit_with_percent pricing

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(unit_amount:, percent:) ⇒ UnitWithPercentConfig1

Returns a new instance of UnitWithPercentConfig1.



38
39
40
41
# File 'lib/api_reference/models/unit_with_percent_config1.rb', line 38

def initialize(unit_amount:, percent:)
  @unit_amount = unit_amount
  @percent = percent
end

Instance Attribute Details

#percentString

What percent, out of 100, of the calculated total to charge

Returns:

  • (String)


18
19
20
# File 'lib/api_reference/models/unit_with_percent_config1.rb', line 18

def percent
  @percent
end

#unit_amountString

Rate per unit of usage

Returns:

  • (String)


14
15
16
# File 'lib/api_reference/models/unit_with_percent_config1.rb', line 14

def unit_amount
  @unit_amount
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/api_reference/models/unit_with_percent_config1.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  unit_amount = hash.key?('unit_amount') ? hash['unit_amount'] : nil
  percent = hash.key?('percent') ? hash['percent'] : nil

  # Create object from extracted values.
  UnitWithPercentConfig1.new(unit_amount: unit_amount,
                             percent: percent)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/api_reference/models/unit_with_percent_config1.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['unit_amount'] = 'unit_amount'
  @_hash['percent'] = 'percent'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/api_reference/models/unit_with_percent_config1.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/api_reference/models/unit_with_percent_config1.rb', line 29

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/api_reference/models/unit_with_percent_config1.rb', line 58

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.unit_amount,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.percent,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['unit_amount'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['percent'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
# File 'lib/api_reference/models/unit_with_percent_config1.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} unit_amount: #{@unit_amount.inspect}, percent: #{@percent.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
# File 'lib/api_reference/models/unit_with_percent_config1.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} unit_amount: #{@unit_amount}, percent: #{@percent}>"
end