Class: ApiReference::UnitWithProrationConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::UnitWithProrationConfig
- Defined in:
- lib/api_reference/models/unit_with_proration_config.rb
Overview
Configuration for unit pricing with proration
Instance Attribute Summary collapse
-
#unit_amount ⇒ String
Rate per unit of usage.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(unit_amount:) ⇒ UnitWithProrationConfig
constructor
A new instance of UnitWithProrationConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(unit_amount:) ⇒ UnitWithProrationConfig
Returns a new instance of UnitWithProrationConfig.
33 34 35 |
# File 'lib/api_reference/models/unit_with_proration_config.rb', line 33 def initialize(unit_amount:) @unit_amount = unit_amount end |
Instance Attribute Details
#unit_amount ⇒ String
Rate per unit of usage
14 15 16 |
# File 'lib/api_reference/models/unit_with_proration_config.rb', line 14 def unit_amount @unit_amount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 |
# File 'lib/api_reference/models/unit_with_proration_config.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. unit_amount = hash.key?('unit_amount') ? hash['unit_amount'] : nil # Create object from extracted values. UnitWithProrationConfig.new(unit_amount: unit_amount) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/api_reference/models/unit_with_proration_config.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['unit_amount'] = 'unit_amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/api_reference/models/unit_with_proration_config.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/api_reference/models/unit_with_proration_config.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
55 56 57 58 |
# File 'lib/api_reference/models/unit_with_proration_config.rb', line 55 def inspect class_name = self.class.name.split('::').last "<#{class_name} unit_amount: #{@unit_amount.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
49 50 51 52 |
# File 'lib/api_reference/models/unit_with_proration_config.rb', line 49 def to_s class_name = self.class.name.split('::').last "<#{class_name} unit_amount: #{@unit_amount}>" end |