Class: ApiReference::UnscheduleFixedFeeQuantityChangeParams
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::UnscheduleFixedFeeQuantityChangeParams
- Defined in:
- lib/api_reference/models/unschedule_fixed_fee_quantity_change_params.rb
Overview
UnscheduleFixedFeeQuantityChangeParams Model.
Instance Attribute Summary collapse
-
#price_id ⇒ String
Price for which the updates should be cleared.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(price_id:) ⇒ UnscheduleFixedFeeQuantityChangeParams
constructor
A new instance of UnscheduleFixedFeeQuantityChangeParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(price_id:) ⇒ UnscheduleFixedFeeQuantityChangeParams
Returns a new instance of UnscheduleFixedFeeQuantityChangeParams.
33 34 35 |
# File 'lib/api_reference/models/unschedule_fixed_fee_quantity_change_params.rb', line 33 def initialize(price_id:) @price_id = price_id end |
Instance Attribute Details
#price_id ⇒ String
Price for which the updates should be cleared. Must be a fixed fee.
14 15 16 |
# File 'lib/api_reference/models/unschedule_fixed_fee_quantity_change_params.rb', line 14 def price_id @price_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 |
# File 'lib/api_reference/models/unschedule_fixed_fee_quantity_change_params.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. price_id = hash.key?('price_id') ? hash['price_id'] : nil # Create object from extracted values. UnscheduleFixedFeeQuantityChangeParams.new(price_id: price_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/api_reference/models/unschedule_fixed_fee_quantity_change_params.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['price_id'] = 'price_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/api_reference/models/unschedule_fixed_fee_quantity_change_params.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/api_reference/models/unschedule_fixed_fee_quantity_change_params.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
55 56 57 58 |
# File 'lib/api_reference/models/unschedule_fixed_fee_quantity_change_params.rb', line 55 def inspect class_name = self.class.name.split('::').last "<#{class_name} price_id: #{@price_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
49 50 51 52 |
# File 'lib/api_reference/models/unschedule_fixed_fee_quantity_change_params.rb', line 49 def to_s class_name = self.class.name.split('::').last "<#{class_name} price_id: #{@price_id}>" end |