Class: ApiReference::UpdateAlertQueryParams
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::UpdateAlertQueryParams
- Defined in:
- lib/api_reference/models/update_alert_query_params.rb
Overview
UpdateAlertQueryParams Model.
Instance Attribute Summary collapse
-
#subscription_id ⇒ String
Used to update the status of a plan alert scoped to this subscription_id.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(subscription_id: SKIP) ⇒ UpdateAlertQueryParams
constructor
A new instance of UpdateAlertQueryParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(subscription_id: SKIP) ⇒ UpdateAlertQueryParams
Returns a new instance of UpdateAlertQueryParams.
37 38 39 |
# File 'lib/api_reference/models/update_alert_query_params.rb', line 37 def initialize(subscription_id: SKIP) @subscription_id = subscription_id unless subscription_id == SKIP end |
Instance Attribute Details
#subscription_id ⇒ String
Used to update the status of a plan alert scoped to this subscription_id
14 15 16 |
# File 'lib/api_reference/models/update_alert_query_params.rb', line 14 def subscription_id @subscription_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 51 |
# File 'lib/api_reference/models/update_alert_query_params.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. subscription_id = hash.key?('subscription_id') ? hash['subscription_id'] : SKIP # Create object from extracted values. UpdateAlertQueryParams.new(subscription_id: subscription_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/api_reference/models/update_alert_query_params.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['subscription_id'] = 'subscription_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 34 35 |
# File 'lib/api_reference/models/update_alert_query_params.rb', line 31 def self.nullables %w[ subscription_id ] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/api_reference/models/update_alert_query_params.rb', line 24 def self.optionals %w[ subscription_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
60 61 62 63 |
# File 'lib/api_reference/models/update_alert_query_params.rb', line 60 def inspect class_name = self.class.name.split('::').last "<#{class_name} subscription_id: #{@subscription_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
54 55 56 57 |
# File 'lib/api_reference/models/update_alert_query_params.rb', line 54 def to_s class_name = self.class.name.split('::').last "<#{class_name} subscription_id: #{@subscription_id}>" end |