Class: ApiReference::AccountingProviderConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::AccountingProviderConfig
- Defined in:
- lib/api_reference/models/accounting_provider_config.rb
Overview
AccountingProviderConfig Model.
Instance Attribute Summary collapse
-
#external_provider_id ⇒ String
TODO: Write general description for this method.
-
#provider_type ⇒ ProviderType
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(provider_type:, external_provider_id:, additional_properties: nil) ⇒ AccountingProviderConfig
constructor
A new instance of AccountingProviderConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(provider_type:, external_provider_id:, additional_properties: nil) ⇒ AccountingProviderConfig
Returns a new instance of AccountingProviderConfig.
38 39 40 41 42 43 44 45 46 |
# File 'lib/api_reference/models/accounting_provider_config.rb', line 38 def initialize(provider_type:, external_provider_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @provider_type = provider_type @external_provider_id = external_provider_id @additional_properties = additional_properties end |
Instance Attribute Details
#external_provider_id ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/api_reference/models/accounting_provider_config.rb', line 18 def external_provider_id @external_provider_id end |
#provider_type ⇒ ProviderType
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/accounting_provider_config.rb', line 14 def provider_type @provider_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/api_reference/models/accounting_provider_config.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. provider_type = hash.key?('provider_type') ? hash['provider_type'] : nil external_provider_id = hash.key?('external_provider_id') ? hash['external_provider_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountingProviderConfig.new(provider_type: provider_type, external_provider_id: external_provider_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/api_reference/models/accounting_provider_config.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['provider_type'] = 'provider_type' @_hash['external_provider_id'] = 'external_provider_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/api_reference/models/accounting_provider_config.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/api_reference/models/accounting_provider_config.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/api_reference/models/accounting_provider_config.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} provider_type: #{@provider_type.inspect}, external_provider_id:"\ " #{@external_provider_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/api_reference/models/accounting_provider_config.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} provider_type: #{@provider_type}, external_provider_id:"\ " #{@external_provider_id}, additional_properties: #{@additional_properties}>" end |