Class: ApiReference::BalanceAlertStatus
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::BalanceAlertStatus
- Defined in:
- lib/api_reference/models/balance_alert_status.rb
Overview
Alert status is used to determine if an alert is currently in-alert or not.
Instance Attribute Summary collapse
-
#in_alert ⇒ TrueClass | FalseClass
Whether the alert is currently in-alert or not.
-
#threshold_value ⇒ Float
The value of the threshold that defines the alert status.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(threshold_value:, in_alert:, additional_properties: nil) ⇒ BalanceAlertStatus
constructor
A new instance of BalanceAlertStatus.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(threshold_value:, in_alert:, additional_properties: nil) ⇒ BalanceAlertStatus
Returns a new instance of BalanceAlertStatus.
38 39 40 41 42 43 44 45 |
# File 'lib/api_reference/models/balance_alert_status.rb', line 38 def initialize(threshold_value:, in_alert:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @threshold_value = threshold_value @in_alert = in_alert @additional_properties = additional_properties end |
Instance Attribute Details
#in_alert ⇒ TrueClass | FalseClass
Whether the alert is currently in-alert or not.
18 19 20 |
# File 'lib/api_reference/models/balance_alert_status.rb', line 18 def in_alert @in_alert end |
#threshold_value ⇒ Float
The value of the threshold that defines the alert status.
14 15 16 |
# File 'lib/api_reference/models/balance_alert_status.rb', line 14 def threshold_value @threshold_value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/api_reference/models/balance_alert_status.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. threshold_value = hash.key?('threshold_value') ? hash['threshold_value'] : nil in_alert = hash.key?('in_alert') ? hash['in_alert'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BalanceAlertStatus.new(threshold_value: threshold_value, in_alert: in_alert, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/api_reference/models/balance_alert_status.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['threshold_value'] = 'threshold_value' @_hash['in_alert'] = 'in_alert' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/api_reference/models/balance_alert_status.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/api_reference/models/balance_alert_status.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/api_reference/models/balance_alert_status.rb', line 71 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.threshold_value, ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value.in_alert, ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['threshold_value'], ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value['in_alert'], ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/api_reference/models/balance_alert_status.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} threshold_value: #{@threshold_value.inspect}, in_alert:"\ " #{@in_alert.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/api_reference/models/balance_alert_status.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} threshold_value: #{@threshold_value}, in_alert: #{@in_alert},"\ " additional_properties: #{@additional_properties}>" end |