Class: ApiReference::CustomerHierarchy2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::CustomerHierarchy2
- Defined in:
- lib/api_reference/models/customer_hierarchy2.rb
Overview
The hierarchical relationships for this customer.
Instance Attribute Summary collapse
-
#children ⇒ Array[CustomerMinified]
TODO: Write general description for this method.
-
#parent ⇒ CustomerMinified
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(parent:, children:, additional_properties: nil) ⇒ CustomerHierarchy2
constructor
A new instance of CustomerHierarchy2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(parent:, children:, additional_properties: nil) ⇒ CustomerHierarchy2
Returns a new instance of CustomerHierarchy2.
40 41 42 43 44 45 46 47 |
# File 'lib/api_reference/models/customer_hierarchy2.rb', line 40 def initialize(parent:, children:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @parent = parent @children = children @additional_properties = additional_properties end |
Instance Attribute Details
#children ⇒ Array[CustomerMinified]
TODO: Write general description for this method
18 19 20 |
# File 'lib/api_reference/models/customer_hierarchy2.rb', line 18 def children @children end |
#parent ⇒ CustomerMinified
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/customer_hierarchy2.rb', line 14 def parent @parent end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/api_reference/models/customer_hierarchy2.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. parent = CustomerMinified.from_hash(hash['parent']) if hash['parent'] # Parameter is an array, so we need to iterate through it children = nil unless hash['children'].nil? children = [] hash['children'].each do |structure| children << (CustomerMinified.from_hash(structure) if structure) end end children = nil unless hash.key?('children') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CustomerHierarchy2.new(parent: parent, children: children, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/api_reference/models/customer_hierarchy2.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['parent'] = 'parent' @_hash['children'] = 'children' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 37 38 |
# File 'lib/api_reference/models/customer_hierarchy2.rb', line 34 def self.nullables %w[ parent ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/api_reference/models/customer_hierarchy2.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/api_reference/models/customer_hierarchy2.rb', line 81 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.parent, ->(val) { CustomerMinified.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value.children, ->(val) { CustomerMinified.validate(val) }, is_model_hash: true, is_inner_model_hash: true) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['parent'], ->(val) { CustomerMinified.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value['children'], ->(val) { CustomerMinified.validate(val) }, is_model_hash: true, is_inner_model_hash: true) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
115 116 117 118 119 |
# File 'lib/api_reference/models/customer_hierarchy2.rb', line 115 def inspect class_name = self.class.name.split('::').last "<#{class_name} parent: #{@parent.inspect}, children: #{@children.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 |
# File 'lib/api_reference/models/customer_hierarchy2.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} parent: #{@parent}, children: #{@children}, additional_properties:"\ " #{@additional_properties}>" end |