Class: ApiReference::CustomerHierarchyConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::CustomerHierarchyConfig
- Defined in:
- lib/api_reference/models/customer_hierarchy_config.rb
Overview
CustomerHierarchyConfig Model.
Instance Attribute Summary collapse
-
#child_customer_ids ⇒ Array[String]
A list of child customer IDs to add to the hierarchy.
-
#parent_customer_id ⇒ String
The ID of the parent customer in the hierarchy.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(parent_customer_id: SKIP, child_customer_ids: SKIP, additional_properties: nil) ⇒ CustomerHierarchyConfig
constructor
A new instance of CustomerHierarchyConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(parent_customer_id: SKIP, child_customer_ids: SKIP, additional_properties: nil) ⇒ CustomerHierarchyConfig
Returns a new instance of CustomerHierarchyConfig.
45 46 47 48 49 50 51 52 53 |
# File 'lib/api_reference/models/customer_hierarchy_config.rb', line 45 def initialize(parent_customer_id: SKIP, child_customer_ids: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @parent_customer_id = parent_customer_id unless parent_customer_id == SKIP @child_customer_ids = child_customer_ids unless child_customer_ids == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#child_customer_ids ⇒ Array[String]
A list of child customer IDs to add to the hierarchy. The desired child customers must not already be part of another hierarchy.
20 21 22 |
# File 'lib/api_reference/models/customer_hierarchy_config.rb', line 20 def child_customer_ids @child_customer_ids end |
#parent_customer_id ⇒ String
The ID of the parent customer in the hierarchy. The desired parent customer must not be a child of another customer.
15 16 17 |
# File 'lib/api_reference/models/customer_hierarchy_config.rb', line 15 def parent_customer_id @parent_customer_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/api_reference/models/customer_hierarchy_config.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. parent_customer_id = hash.key?('parent_customer_id') ? hash['parent_customer_id'] : SKIP child_customer_ids = hash.key?('child_customer_ids') ? hash['child_customer_ids'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CustomerHierarchyConfig.new(parent_customer_id: parent_customer_id, child_customer_ids: child_customer_ids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/api_reference/models/customer_hierarchy_config.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['parent_customer_id'] = 'parent_customer_id' @_hash['child_customer_ids'] = 'child_customer_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 42 43 |
# File 'lib/api_reference/models/customer_hierarchy_config.rb', line 39 def self.nullables %w[ parent_customer_id ] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/api_reference/models/customer_hierarchy_config.rb', line 31 def self.optionals %w[ parent_customer_id child_customer_ids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/api_reference/models/customer_hierarchy_config.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} parent_customer_id: #{@parent_customer_id.inspect}, child_customer_ids:"\ " #{@child_customer_ids.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/api_reference/models/customer_hierarchy_config.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} parent_customer_id: #{@parent_customer_id}, child_customer_ids:"\ " #{@child_customer_ids}, additional_properties: #{@additional_properties}>" end |