Class: ApiReference::DiscountOverride
- Defined in:
- lib/api_reference/models/discount_override.rb
Overview
DiscountOverride Model.
Instance Attribute Summary collapse
-
#amount_discount ⇒ String
Only available if discount_type is
amount. -
#discount_type ⇒ DiscountType
TODO: Write general description for this method.
-
#percentage_discount ⇒ Float
Only available if discount_type is
percentage. -
#usage_discount ⇒ Float
Only available if discount_type is
usage.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(discount_type:, percentage_discount: SKIP, usage_discount: SKIP, amount_discount: SKIP, additional_properties: nil) ⇒ DiscountOverride
constructor
A new instance of DiscountOverride.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(discount_type:, percentage_discount: SKIP, usage_discount: SKIP, amount_discount: SKIP, additional_properties: nil) ⇒ DiscountOverride
Returns a new instance of DiscountOverride.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/api_reference/models/discount_override.rb', line 58 def initialize(discount_type:, percentage_discount: SKIP, usage_discount: SKIP, amount_discount: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @discount_type = discount_type @percentage_discount = percentage_discount unless percentage_discount == SKIP @usage_discount = usage_discount unless usage_discount == SKIP @amount_discount = amount_discount unless amount_discount == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount_discount ⇒ String
Only available if discount_type is amount.
28 29 30 |
# File 'lib/api_reference/models/discount_override.rb', line 28 def amount_discount @amount_discount end |
#discount_type ⇒ DiscountType
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/discount_override.rb', line 14 def discount_type @discount_type end |
#percentage_discount ⇒ Float
Only available if discount_type is percentage. This is a number between
0 and 1.
19 20 21 |
# File 'lib/api_reference/models/discount_override.rb', line 19 def percentage_discount @percentage_discount end |
#usage_discount ⇒ Float
Only available if discount_type is usage. Number of usage units that
this discount is for
24 25 26 |
# File 'lib/api_reference/models/discount_override.rb', line 24 def usage_discount @usage_discount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/api_reference/models/discount_override.rb', line 72 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. discount_type = hash.key?('discount_type') ? hash['discount_type'] : nil percentage_discount = hash.key?('percentage_discount') ? hash['percentage_discount'] : SKIP usage_discount = hash.key?('usage_discount') ? hash['usage_discount'] : SKIP amount_discount = hash.key?('amount_discount') ? hash['amount_discount'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DiscountOverride.new(discount_type: discount_type, percentage_discount: percentage_discount, usage_discount: usage_discount, amount_discount: amount_discount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 37 38 |
# File 'lib/api_reference/models/discount_override.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['discount_type'] = 'discount_type' @_hash['percentage_discount'] = 'percentage_discount' @_hash['usage_discount'] = 'usage_discount' @_hash['amount_discount'] = 'amount_discount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 53 54 55 56 |
# File 'lib/api_reference/models/discount_override.rb', line 50 def self.nullables %w[ percentage_discount usage_discount amount_discount ] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 44 45 46 47 |
# File 'lib/api_reference/models/discount_override.rb', line 41 def self.optionals %w[ percentage_discount usage_discount amount_discount ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
108 109 110 111 112 113 114 |
# File 'lib/api_reference/models/discount_override.rb', line 108 def inspect class_name = self.class.name.split('::').last "<#{class_name} discount_type: #{@discount_type.inspect}, percentage_discount:"\ " #{@percentage_discount.inspect}, usage_discount: #{@usage_discount.inspect},"\ " amount_discount: #{@amount_discount.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 105 |
# File 'lib/api_reference/models/discount_override.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} discount_type: #{@discount_type}, percentage_discount:"\ " #{@percentage_discount}, usage_discount: #{@usage_discount}, amount_discount:"\ " #{@amount_discount}, additional_properties: #{@additional_properties}>" end |