Class: ApiReference::FilterRule
- Defined in:
- lib/api_reference/models/filter_rule.rb
Overview
Configuration for a single property filter
Instance Attribute Summary collapse
-
#property_key ⇒ String
Event property key to filter on.
-
#property_value ⇒ String
Event property value to match.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(property_key:, property_value:) ⇒ FilterRule
constructor
A new instance of FilterRule.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(property_key:, property_value:) ⇒ FilterRule
Returns a new instance of FilterRule.
38 39 40 41 |
# File 'lib/api_reference/models/filter_rule.rb', line 38 def initialize(property_key:, property_value:) @property_key = property_key @property_value = property_value end |
Instance Attribute Details
#property_key ⇒ String
Event property key to filter on
14 15 16 |
# File 'lib/api_reference/models/filter_rule.rb', line 14 def property_key @property_key end |
#property_value ⇒ String
Event property value to match
18 19 20 |
# File 'lib/api_reference/models/filter_rule.rb', line 18 def property_value @property_value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/api_reference/models/filter_rule.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. property_key = hash.key?('property_key') ? hash['property_key'] : nil property_value = hash.key?('property_value') ? hash['property_value'] : nil # Create object from extracted values. FilterRule.new(property_key: property_key, property_value: property_value) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/api_reference/models/filter_rule.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['property_key'] = 'property_key' @_hash['property_value'] = 'property_value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/api_reference/models/filter_rule.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/api_reference/models/filter_rule.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/api_reference/models/filter_rule.rb', line 59 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.property_key, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.property_value, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['property_key'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['property_value'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/api_reference/models/filter_rule.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} property_key: #{@property_key.inspect}, property_value:"\ " #{@property_value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 |
# File 'lib/api_reference/models/filter_rule.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} property_key: #{@property_key}, property_value: #{@property_value}>" end |