Class: ApiReference::IncrementLedgerEntry
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::IncrementLedgerEntry
- Defined in:
- lib/api_reference/models/increment_ledger_entry.rb
Overview
IncrementLedgerEntry Model.
Instance Attribute Summary collapse
-
#amount ⇒ Float
User specified key-value pairs for the resource.
-
#created_at ⇒ DateTime
User specified key-value pairs for the resource.
-
#created_invoices ⇒ Array[Invoice]
If the increment resulted in invoice creation, the list of created invoices.
-
#credit_block ⇒ AffectedBlock
User specified key-value pairs for the resource.
-
#currency ⇒ String
User specified key-value pairs for the resource.
-
#customer ⇒ CustomerMinified
User specified key-value pairs for the resource.
-
#description ⇒ String
User specified key-value pairs for the resource.
-
#ending_balance ⇒ Float
User specified key-value pairs for the resource.
-
#entry_status ⇒ EntryStatus
User specified key-value pairs for the resource.
-
#entry_type ⇒ String
readonly
User specified key-value pairs for the resource.
-
#id ⇒ String
User specified key-value pairs for the resource.
-
#ledger_sequence_number ⇒ Integer
User specified key-value pairs for the resource.
-
#metadata ⇒ Hash[String, String]
User specified key-value pairs for the resource.
-
#starting_balance ⇒ Float
User specified key-value pairs for the resource.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(metadata:, id:, ledger_sequence_number:, entry_status:, customer:, starting_balance:, ending_balance:, amount:, currency:, created_at:, description:, credit_block:, created_invoices: SKIP, additional_properties: nil) ⇒ IncrementLedgerEntry
constructor
A new instance of IncrementLedgerEntry.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_created_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(metadata:, id:, ledger_sequence_number:, entry_status:, customer:, starting_balance:, ending_balance:, amount:, currency:, created_at:, description:, credit_block:, created_invoices: SKIP, additional_properties: nil) ⇒ IncrementLedgerEntry
Returns a new instance of IncrementLedgerEntry.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 144 def initialize(metadata:, id:, ledger_sequence_number:, entry_status:, customer:, starting_balance:, ending_balance:, amount:, currency:, created_at:, description:, credit_block:, created_invoices: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @metadata = @id = id @ledger_sequence_number = ledger_sequence_number @entry_status = entry_status @customer = customer @starting_balance = starting_balance @ending_balance = ending_balance @amount = amount @currency = currency @created_at = created_at @description = description @credit_block = credit_block @entry_type = 'increment' @created_invoices = created_invoices unless created_invoices == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Float
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
67 68 69 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 67 def amount @amount end |
#created_at ⇒ DateTime
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
81 82 83 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 81 def created_at @created_at end |
#created_invoices ⇒ Array[Invoice]
If the increment resulted in invoice creation, the list of created invoices
107 108 109 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 107 def created_invoices @created_invoices end |
#credit_block ⇒ AffectedBlock
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
95 96 97 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 95 def credit_block @credit_block end |
#currency ⇒ String
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
74 75 76 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 74 def currency @currency end |
#customer ⇒ CustomerMinified
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
46 47 48 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 46 def customer @customer end |
#description ⇒ String
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
88 89 90 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 88 def description @description end |
#ending_balance ⇒ Float
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
60 61 62 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 60 def ending_balance @ending_balance end |
#entry_status ⇒ EntryStatus
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
39 40 41 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 39 def entry_status @entry_status end |
#entry_type ⇒ String (readonly)
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
102 103 104 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 102 def entry_type @entry_type end |
#id ⇒ String
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
25 26 27 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 25 def id @id end |
#ledger_sequence_number ⇒ Integer
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
32 33 34 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 32 def ledger_sequence_number @ledger_sequence_number end |
#metadata ⇒ Hash[String, String]
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
18 19 20 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 18 def @metadata end |
#starting_balance ⇒ Float
User specified key-value pairs for the resource. If not present, this
defaults to an empty dictionary. Individual keys can be removed by setting
the value to null, and the entire metadata mapping can be cleared by
setting metadata to null.
53 54 55 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 53 def starting_balance @starting_balance end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 169 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash.key?('metadata') ? hash['metadata'] : nil id = hash.key?('id') ? hash['id'] : nil ledger_sequence_number = hash.key?('ledger_sequence_number') ? hash['ledger_sequence_number'] : nil entry_status = hash.key?('entry_status') ? hash['entry_status'] : nil customer = CustomerMinified.from_hash(hash['customer']) if hash['customer'] starting_balance = hash.key?('starting_balance') ? hash['starting_balance'] : nil ending_balance = hash.key?('ending_balance') ? hash['ending_balance'] : nil amount = hash.key?('amount') ? hash['amount'] : nil currency = hash.key?('currency') ? hash['currency'] : nil created_at = if hash.key?('created_at') (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at']) end description = hash.key?('description') ? hash['description'] : nil credit_block = AffectedBlock.from_hash(hash['credit_block']) if hash['credit_block'] # Parameter is an array, so we need to iterate through it created_invoices = nil unless hash['created_invoices'].nil? created_invoices = [] hash['created_invoices'].each do |structure| created_invoices << (Invoice.from_hash(structure) if structure) end end created_invoices = SKIP unless hash.key?('created_invoices') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IncrementLedgerEntry.new(metadata: , id: id, ledger_sequence_number: ledger_sequence_number, entry_status: entry_status, customer: customer, starting_balance: starting_balance, ending_balance: ending_balance, amount: amount, currency: currency, created_at: created_at, description: description, credit_block: credit_block, created_invoices: created_invoices, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 110 def self.names @_hash = {} if @_hash.nil? @_hash['metadata'] = 'metadata' @_hash['id'] = 'id' @_hash['ledger_sequence_number'] = 'ledger_sequence_number' @_hash['entry_status'] = 'entry_status' @_hash['customer'] = 'customer' @_hash['starting_balance'] = 'starting_balance' @_hash['ending_balance'] = 'ending_balance' @_hash['amount'] = 'amount' @_hash['currency'] = 'currency' @_hash['created_at'] = 'created_at' @_hash['description'] = 'description' @_hash['credit_block'] = 'credit_block' @_hash['entry_type'] = 'entry_type' @_hash['created_invoices'] = 'created_invoices' @_hash end |
.nullables ⇒ Object
An array for nullable fields
137 138 139 140 141 142 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 137 def self.nullables %w[ description created_invoices ] end |
.optionals ⇒ Object
An array for optional fields
130 131 132 133 134 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 130 def self.optionals %w[ created_invoices ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 231 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value., ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.id, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.ledger_sequence_number, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.entry_status, ->(val) { EntryStatus.validate(val) }) and APIHelper.valid_type?(value.customer, ->(val) { CustomerMinified.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value.starting_balance, ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value.ending_balance, ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value.amount, ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value.currency, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.created_at, ->(val) { val.instance_of? DateTime }) and APIHelper.valid_type?(value.description, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.credit_block, ->(val) { AffectedBlock.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value.entry_type, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['metadata'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['id'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['ledger_sequence_number'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['entry_status'], ->(val) { EntryStatus.validate(val) }) and APIHelper.valid_type?(value['customer'], ->(val) { CustomerMinified.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value['starting_balance'], ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value['ending_balance'], ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value['amount'], ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value['currency'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['created_at'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['description'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['credit_block'], ->(val) { AffectedBlock.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value['entry_type'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
311 312 313 314 315 316 317 318 319 320 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 311 def inspect class_name = self.class.name.split('::').last "<#{class_name} metadata: #{@metadata.inspect}, id: #{@id.inspect}, ledger_sequence_number:"\ " #{@ledger_sequence_number.inspect}, entry_status: #{@entry_status.inspect}, customer:"\ " #{@customer.inspect}, starting_balance: #{@starting_balance.inspect}, ending_balance:"\ " #{@ending_balance.inspect}, amount: #{@amount.inspect}, currency: #{@currency.inspect},"\ " created_at: #{@created_at.inspect}, description: #{@description.inspect}, credit_block:"\ " #{@credit_block.inspect}, entry_type: #{@entry_type.inspect}, created_invoices:"\ " #{@created_invoices.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_created_at ⇒ Object
225 226 227 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 225 def to_custom_created_at DateTimeHelper.to_rfc3339(created_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
300 301 302 303 304 305 306 307 308 |
# File 'lib/api_reference/models/increment_ledger_entry.rb', line 300 def to_s class_name = self.class.name.split('::').last "<#{class_name} metadata: #{@metadata}, id: #{@id}, ledger_sequence_number:"\ " #{@ledger_sequence_number}, entry_status: #{@entry_status}, customer: #{@customer},"\ " starting_balance: #{@starting_balance}, ending_balance: #{@ending_balance}, amount:"\ " #{@amount}, currency: #{@currency}, created_at: #{@created_at}, description:"\ " #{@description}, credit_block: #{@credit_block}, entry_type: #{@entry_type},"\ " created_invoices: #{@created_invoices}, additional_properties: #{@additional_properties}>" end |