Class: ApiReference::LicenseType
- Defined in:
- lib/api_reference/models/license_type.rb
Overview
The LicenseType resource represents a type of license that can be assigned to users. License types are used during billing by grouping metrics on the configured grouping key.
Instance Attribute Summary collapse
-
#grouping_key ⇒ String
The key used for grouping licenses of this type.
-
#id ⇒ String
The Orb-assigned unique identifier for the license type.
-
#name ⇒ String
The name of the license type.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(id:, name:, grouping_key:, additional_properties: nil) ⇒ LicenseType
constructor
A new instance of LicenseType.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, name:, grouping_key:, additional_properties: nil) ⇒ LicenseType
Returns a new instance of LicenseType.
46 47 48 49 50 51 52 53 54 |
# File 'lib/api_reference/models/license_type.rb', line 46 def initialize(id:, name:, grouping_key:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @name = name @grouping_key = grouping_key @additional_properties = additional_properties end |
Instance Attribute Details
#grouping_key ⇒ String
The key used for grouping licenses of this type. This is typically a user identifier field.
25 26 27 |
# File 'lib/api_reference/models/license_type.rb', line 25 def grouping_key @grouping_key end |
#id ⇒ String
The Orb-assigned unique identifier for the license type.
16 17 18 |
# File 'lib/api_reference/models/license_type.rb', line 16 def id @id end |
#name ⇒ String
The name of the license type.
20 21 22 |
# File 'lib/api_reference/models/license_type.rb', line 20 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/api_reference/models/license_type.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil grouping_key = hash.key?('grouping_key') ? hash['grouping_key'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LicenseType.new(id: id, name: name, grouping_key: grouping_key, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/api_reference/models/license_type.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['grouping_key'] = 'grouping_key' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/api_reference/models/license_type.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 |
# File 'lib/api_reference/models/license_type.rb', line 37 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/api_reference/models/license_type.rb', line 81 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.id, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.grouping_key, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['id'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['grouping_key'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
113 114 115 116 117 |
# File 'lib/api_reference/models/license_type.rb', line 113 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, grouping_key:"\ " #{@grouping_key.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 |
# File 'lib/api_reference/models/license_type.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, name: #{@name}, grouping_key: #{@grouping_key},"\ " additional_properties: #{@additional_properties}>" end |