Class: ApiReference::LicenseTypeApi
- Defined in:
- lib/api_reference/apis/license_type_api.rb
Overview
LicenseTypeApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#create_license_type(body) ⇒ ApiResponse
This endpoint is used to create a new license type.
-
#fetch_license_type(license_type_id) ⇒ ApiResponse
This endpoint returns a license type identified by its license_type_id.
-
#list_license_types(limit: 20, cursor: nil) ⇒ ApiResponse
This endpoint returns a list of all license types configured for the account, ordered in ascending order by creation time.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from ApiReference::BaseApi
Instance Method Details
#create_license_type(body) ⇒ ApiResponse
This endpoint is used to create a new license type. License types are used to group licenses and define billing behavior. Each license type has a name and a grouping key that determines how metrics are aggregated for billing purposes. here
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/api_reference/apis/license_type_api.rb', line 64 def create_license_type(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/license_types', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Single.new('APIKeyAuth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(LicenseType.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', APIException) .local_error('401', 'Unauthorized', AuthorizationErrorException) .local_error('404', 'Not Found', APIException) .local_error('409', 'Conflict', IdempotencyRequestMismatchException) .local_error('413', 'Content Too Large', APIException) .local_error('429', 'Too Many Requests', TooManyRequestsException) .local_error('500', 'Internal Server Error', ServerErrorException)) .execute end |
#fetch_license_type(license_type_id) ⇒ ApiResponse
This endpoint returns a license type identified by its license_type_id. Use this endpoint to retrieve details about a specific license type, including its name and grouping key. here
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/api_reference/apis/license_type_api.rb', line 109 def fetch_license_type(license_type_id) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/license_types/{license_type_id}', Server::DEFAULT) .template_param(new_parameter(license_type_id, key: 'license_type_id') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('APIKeyAuth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(LicenseType.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', APIException) .local_error('401', 'Unauthorized', AuthorizationErrorException) .local_error('404', 'Not Found', APIException) .local_error('409', 'Conflict', IdempotencyRequestMismatchException) .local_error('413', 'Content Too Large', APIException) .local_error('429', 'Too Many Requests', TooManyRequestsException) .local_error('500', 'Internal Server Error', ServerErrorException)) .execute end |
#list_license_types(limit: 20, cursor: nil) ⇒ ApiResponse
This endpoint returns a list of all license types configured for the account, ordered in ascending order by creation time. License types are used to group licenses and define billing behavior. Each license type has a name and a grouping key that determines how metrics are aggregated for billing purposes.
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/api_reference/apis/license_type_api.rb', line 18 def list_license_types(limit: 20, cursor: nil) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/license_types', Server::DEFAULT) .query_param(new_parameter(limit, key: 'limit')) .query_param(new_parameter(cursor, key: 'cursor')) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('APIKeyAuth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(LicenseTypes.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', APIException) .local_error('401', 'Unauthorized', AuthorizationErrorException) .local_error('404', 'Not Found', APIException) .local_error('409', 'Conflict', IdempotencyRequestMismatchException) .local_error('413', 'Content Too Large', APIException) .local_error('429', 'Too Many Requests', TooManyRequestsException) .local_error('500', 'Internal Server Error', ServerErrorException)) .execute end |