Class: ApiReference::MatrixWithDisplayNameUnitAmountItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::MatrixWithDisplayNameUnitAmountItem
- Defined in:
- lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb
Overview
Configuration for a unit amount item
Instance Attribute Summary collapse
-
#dimension_value ⇒ String
The dimension value.
-
#display_name ⇒ String
Display name for this dimension value.
-
#unit_amount ⇒ String
Per unit amount.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(display_name:, dimension_value:, unit_amount:) ⇒ MatrixWithDisplayNameUnitAmountItem
constructor
A new instance of MatrixWithDisplayNameUnitAmountItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(display_name:, dimension_value:, unit_amount:) ⇒ MatrixWithDisplayNameUnitAmountItem
Returns a new instance of MatrixWithDisplayNameUnitAmountItem.
43 44 45 46 47 |
# File 'lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb', line 43 def initialize(display_name:, dimension_value:, unit_amount:) @display_name = display_name @dimension_value = dimension_value @unit_amount = unit_amount end |
Instance Attribute Details
#dimension_value ⇒ String
The dimension value
18 19 20 |
# File 'lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb', line 18 def dimension_value @dimension_value end |
#display_name ⇒ String
Display name for this dimension value
14 15 16 |
# File 'lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb', line 14 def display_name @display_name end |
#unit_amount ⇒ String
Per unit amount
22 23 24 |
# File 'lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb', line 22 def unit_amount @unit_amount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. display_name = hash.key?('display_name') ? hash['display_name'] : nil dimension_value = hash.key?('dimension_value') ? hash['dimension_value'] : nil unit_amount = hash.key?('unit_amount') ? hash['unit_amount'] : nil # Create object from extracted values. MatrixWithDisplayNameUnitAmountItem.new(display_name: display_name, dimension_value: dimension_value, unit_amount: unit_amount) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['display_name'] = 'display_name' @_hash['dimension_value'] = 'dimension_value' @_hash['unit_amount'] = 'unit_amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb', line 34 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb', line 67 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.display_name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.dimension_value, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.unit_amount, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['display_name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['dimension_value'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['unit_amount'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} display_name: #{@display_name.inspect}, dimension_value:"\ " #{@dimension_value.inspect}, unit_amount: #{@unit_amount.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/api_reference/models/matrix_with_display_name_unit_amount_item.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} display_name: #{@display_name}, dimension_value: #{@dimension_value},"\ " unit_amount: #{@unit_amount}>" end |