Class: ApiReference::PackageConfig
- Defined in:
- lib/api_reference/models/package_config.rb
Overview
Configuration for package pricing
Instance Attribute Summary collapse
-
#package_amount ⇒ String
A currency amount to rate usage by.
-
#package_size ⇒ Integer
An integer amount to represent package size.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(package_amount:, package_size:) ⇒ PackageConfig
constructor
A new instance of PackageConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(package_amount:, package_size:) ⇒ PackageConfig
Returns a new instance of PackageConfig.
39 40 41 42 |
# File 'lib/api_reference/models/package_config.rb', line 39 def initialize(package_amount:, package_size:) @package_amount = package_amount @package_size = package_size end |
Instance Attribute Details
#package_amount ⇒ String
A currency amount to rate usage by
14 15 16 |
# File 'lib/api_reference/models/package_config.rb', line 14 def package_amount @package_amount end |
#package_size ⇒ Integer
An integer amount to represent package size. For example, 1000 here would divide usage by 1000 before multiplying by package_amount in rating
19 20 21 |
# File 'lib/api_reference/models/package_config.rb', line 19 def package_size @package_size end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/api_reference/models/package_config.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. package_amount = hash.key?('package_amount') ? hash['package_amount'] : nil package_size = hash.key?('package_size') ? hash['package_size'] : nil # Create object from extracted values. PackageConfig.new(package_amount: package_amount, package_size: package_size) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/api_reference/models/package_config.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['package_amount'] = 'package_amount' @_hash['package_size'] = 'package_size' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/api_reference/models/package_config.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/api_reference/models/package_config.rb', line 30 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/api_reference/models/package_config.rb', line 60 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.package_amount, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.package_size, ->(val) { val.instance_of? Integer }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['package_amount'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['package_size'], ->(val) { val.instance_of? Integer }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/api_reference/models/package_config.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} package_amount: #{@package_amount.inspect}, package_size:"\ " #{@package_size.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 |
# File 'lib/api_reference/models/package_config.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} package_amount: #{@package_amount}, package_size: #{@package_size}>" end |