Class: ApiReference::PackageWithAllocationConfig1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::PackageWithAllocationConfig1
- Defined in:
- lib/api_reference/models/package_with_allocation_config1.rb
Overview
Configuration for package_with_allocation pricing
Instance Attribute Summary collapse
-
#allocation ⇒ String
TODO: Write general description for this method.
-
#package_amount ⇒ String
TODO: Write general description for this method.
-
#package_size ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(package_amount:, package_size:, allocation:) ⇒ PackageWithAllocationConfig1
constructor
A new instance of PackageWithAllocationConfig1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(package_amount:, package_size:, allocation:) ⇒ PackageWithAllocationConfig1
Returns a new instance of PackageWithAllocationConfig1.
43 44 45 46 47 |
# File 'lib/api_reference/models/package_with_allocation_config1.rb', line 43 def initialize(package_amount:, package_size:, allocation:) @package_amount = package_amount @package_size = package_size @allocation = allocation end |
Instance Attribute Details
#allocation ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/api_reference/models/package_with_allocation_config1.rb', line 22 def allocation @allocation end |
#package_amount ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/package_with_allocation_config1.rb', line 14 def package_amount @package_amount end |
#package_size ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/api_reference/models/package_with_allocation_config1.rb', line 18 def package_size @package_size end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/api_reference/models/package_with_allocation_config1.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. package_amount = hash.key?('package_amount') ? hash['package_amount'] : nil package_size = hash.key?('package_size') ? hash['package_size'] : nil allocation = hash.key?('allocation') ? hash['allocation'] : nil # Create object from extracted values. PackageWithAllocationConfig1.new(package_amount: package_amount, package_size: package_size, allocation: allocation) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/api_reference/models/package_with_allocation_config1.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['package_amount'] = 'package_amount' @_hash['package_size'] = 'package_size' @_hash['allocation'] = 'allocation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/api_reference/models/package_with_allocation_config1.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/api_reference/models/package_with_allocation_config1.rb', line 34 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/api_reference/models/package_with_allocation_config1.rb', line 67 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.package_amount, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.package_size, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.allocation, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['package_amount'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['package_size'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['allocation'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/api_reference/models/package_with_allocation_config1.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} package_amount: #{@package_amount.inspect}, package_size:"\ " #{@package_size.inspect}, allocation: #{@allocation.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/api_reference/models/package_with_allocation_config1.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} package_amount: #{@package_amount}, package_size: #{@package_size},"\ " allocation: #{@allocation}>" end |