Class: ApiReference::PriceFilter
- Defined in:
- lib/api_reference/models/price_filter.rb
Overview
PriceFilter Model.
Instance Attribute Summary collapse
-
#field ⇒ Field
The property of the price to filter on.
-
#operator ⇒ Operator
Should prices that match the filter be included or excluded.
-
#values ⇒ Array[String]
The IDs or values that match this filter.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(field:, operator:, values:, additional_properties: nil) ⇒ PriceFilter
constructor
A new instance of PriceFilter.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(field:, operator:, values:, additional_properties: nil) ⇒ PriceFilter
Returns a new instance of PriceFilter.
43 44 45 46 47 48 49 50 51 |
# File 'lib/api_reference/models/price_filter.rb', line 43 def initialize(field:, operator:, values:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @field = field @operator = operator @values = values @additional_properties = additional_properties end |
Instance Attribute Details
#field ⇒ Field
The property of the price to filter on.
14 15 16 |
# File 'lib/api_reference/models/price_filter.rb', line 14 def field @field end |
#operator ⇒ Operator
Should prices that match the filter be included or excluded.
18 19 20 |
# File 'lib/api_reference/models/price_filter.rb', line 18 def operator @operator end |
#values ⇒ Array[String]
The IDs or values that match this filter.
22 23 24 |
# File 'lib/api_reference/models/price_filter.rb', line 22 def values @values end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/api_reference/models/price_filter.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. field = hash.key?('field') ? hash['field'] : nil operator = hash.key?('operator') ? hash['operator'] : nil values = hash.key?('values') ? hash['values'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PriceFilter.new(field: field, operator: operator, values: values, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/api_reference/models/price_filter.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['field'] = 'field' @_hash['operator'] = 'operator' @_hash['values'] = 'values' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/api_reference/models/price_filter.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/api_reference/models/price_filter.rb', line 34 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/api_reference/models/price_filter.rb', line 78 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.field, ->(val) { Field.validate(val) }) and APIHelper.valid_type?(value.operator, ->(val) { Operator.validate(val) }) and APIHelper.valid_type?(value.values, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['field'], ->(val) { Field.validate(val) }) and APIHelper.valid_type?(value['operator'], ->(val) { Operator.validate(val) }) and APIHelper.valid_type?(value['values'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 |
# File 'lib/api_reference/models/price_filter.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} field: #{@field.inspect}, operator: #{@operator.inspect}, values:"\ " #{@values.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 |
# File 'lib/api_reference/models/price_filter.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} field: #{@field}, operator: #{@operator}, values: #{@values},"\ " additional_properties: #{@additional_properties}>" end |