Class: ApiReference::RemoveSubscriptionPriceParams
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::RemoveSubscriptionPriceParams
- Defined in:
- lib/api_reference/models/remove_subscription_price_params.rb
Overview
RemoveSubscriptionPriceParams Model.
Instance Attribute Summary collapse
-
#external_price_id ⇒ String
The external price id of the price to remove on the subscription.
-
#price_id ⇒ String
The id of the price to remove on the subscription.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(price_id: SKIP, external_price_id: SKIP, additional_properties: nil) ⇒ RemoveSubscriptionPriceParams
constructor
A new instance of RemoveSubscriptionPriceParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(price_id: SKIP, external_price_id: SKIP, additional_properties: nil) ⇒ RemoveSubscriptionPriceParams
Returns a new instance of RemoveSubscriptionPriceParams.
44 45 46 47 48 49 50 51 52 |
# File 'lib/api_reference/models/remove_subscription_price_params.rb', line 44 def initialize(price_id: SKIP, external_price_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @price_id = price_id unless price_id == SKIP @external_price_id = external_price_id unless external_price_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#external_price_id ⇒ String
The external price id of the price to remove on the subscription.
18 19 20 |
# File 'lib/api_reference/models/remove_subscription_price_params.rb', line 18 def external_price_id @external_price_id end |
#price_id ⇒ String
The id of the price to remove on the subscription.
14 15 16 |
# File 'lib/api_reference/models/remove_subscription_price_params.rb', line 14 def price_id @price_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/api_reference/models/remove_subscription_price_params.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. price_id = hash.key?('price_id') ? hash['price_id'] : SKIP external_price_id = hash.key?('external_price_id') ? hash['external_price_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RemoveSubscriptionPriceParams.new(price_id: price_id, external_price_id: external_price_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/api_reference/models/remove_subscription_price_params.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['price_id'] = 'price_id' @_hash['external_price_id'] = 'external_price_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 42 |
# File 'lib/api_reference/models/remove_subscription_price_params.rb', line 37 def self.nullables %w[ price_id external_price_id ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/api_reference/models/remove_subscription_price_params.rb', line 29 def self.optionals %w[ price_id external_price_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/api_reference/models/remove_subscription_price_params.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} price_id: #{@price_id.inspect}, external_price_id:"\ " #{@external_price_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/api_reference/models/remove_subscription_price_params.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} price_id: #{@price_id}, external_price_id: #{@external_price_id},"\ " additional_properties: #{@additional_properties}>" end |