Class: ApiReference::ReplaceSubscriptionAdjustmentParams
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::ReplaceSubscriptionAdjustmentParams
- Defined in:
- lib/api_reference/models/replace_subscription_adjustment_params.rb
Overview
ReplaceSubscriptionAdjustmentParams Model.
Instance Attribute Summary collapse
-
#adjustment ⇒ Object
The definition of a new adjustment to create and add to the subscription.
-
#replaces_adjustment_id ⇒ String
The id of the adjustment on the plan to replace in the subscription.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(adjustment:, replaces_adjustment_id:, additional_properties: nil) ⇒ ReplaceSubscriptionAdjustmentParams
constructor
A new instance of ReplaceSubscriptionAdjustmentParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(adjustment:, replaces_adjustment_id:, additional_properties: nil) ⇒ ReplaceSubscriptionAdjustmentParams
Returns a new instance of ReplaceSubscriptionAdjustmentParams.
38 39 40 41 42 43 44 45 46 |
# File 'lib/api_reference/models/replace_subscription_adjustment_params.rb', line 38 def initialize(adjustment:, replaces_adjustment_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @adjustment = adjustment @replaces_adjustment_id = replaces_adjustment_id @additional_properties = additional_properties end |
Instance Attribute Details
#adjustment ⇒ Object
The definition of a new adjustment to create and add to the subscription.
14 15 16 |
# File 'lib/api_reference/models/replace_subscription_adjustment_params.rb', line 14 def adjustment @adjustment end |
#replaces_adjustment_id ⇒ String
The id of the adjustment on the plan to replace in the subscription.
18 19 20 |
# File 'lib/api_reference/models/replace_subscription_adjustment_params.rb', line 18 def replaces_adjustment_id @replaces_adjustment_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/api_reference/models/replace_subscription_adjustment_params.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. adjustment = hash.key?('adjustment') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:ReplaceSubscriptionAdjustmentParamsAdjustment), hash['adjustment'] ) : nil replaces_adjustment_id = hash.key?('replaces_adjustment_id') ? hash['replaces_adjustment_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ReplaceSubscriptionAdjustmentParams.new(adjustment: adjustment, replaces_adjustment_id: replaces_adjustment_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/api_reference/models/replace_subscription_adjustment_params.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['adjustment'] = 'adjustment' @_hash['replaces_adjustment_id'] = 'replaces_adjustment_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/api_reference/models/replace_subscription_adjustment_params.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/api_reference/models/replace_subscription_adjustment_params.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/api_reference/models/replace_subscription_adjustment_params.rb', line 74 def self.validate(value) if value.instance_of? self return ( UnionTypeLookUp.get(:ReplaceSubscriptionAdjustmentParamsAdjustment) .validate(value.adjustment) and APIHelper.valid_type?(value.replaces_adjustment_id, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( UnionTypeLookUp.get(:ReplaceSubscriptionAdjustmentParamsAdjustment) .validate(value['adjustment']) and APIHelper.valid_type?(value['replaces_adjustment_id'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 |
# File 'lib/api_reference/models/replace_subscription_adjustment_params.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} adjustment: #{@adjustment.inspect}, replaces_adjustment_id:"\ " #{@replaces_adjustment_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 |
# File 'lib/api_reference/models/replace_subscription_adjustment_params.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} adjustment: #{@adjustment}, replaces_adjustment_id:"\ " #{@replaces_adjustment_id}, additional_properties: #{@additional_properties}>" end |