Class: ApiReference::TaxAmount
- Defined in:
- lib/api_reference/models/tax_amount.rb
Overview
TaxAmount Model.
Instance Attribute Summary collapse
-
#amount ⇒ String
The amount of additional tax incurred by this tax rate.
-
#tax_rate_description ⇒ String
The human-readable description of the applied tax rate.
-
#tax_rate_percentage ⇒ String
The tax rate percentage, out of 100.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(tax_rate_description:, tax_rate_percentage:, amount:, additional_properties: nil) ⇒ TaxAmount
constructor
A new instance of TaxAmount.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_rate_description:, tax_rate_percentage:, amount:, additional_properties: nil) ⇒ TaxAmount
Returns a new instance of TaxAmount.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/api_reference/models/tax_amount.rb', line 45 def initialize(tax_rate_description:, tax_rate_percentage:, amount:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_rate_description = tax_rate_description @tax_rate_percentage = tax_rate_percentage @amount = amount @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ String
The amount of additional tax incurred by this tax rate.
22 23 24 |
# File 'lib/api_reference/models/tax_amount.rb', line 22 def amount @amount end |
#tax_rate_description ⇒ String
The human-readable description of the applied tax rate.
14 15 16 |
# File 'lib/api_reference/models/tax_amount.rb', line 14 def tax_rate_description @tax_rate_description end |
#tax_rate_percentage ⇒ String
The tax rate percentage, out of 100.
18 19 20 |
# File 'lib/api_reference/models/tax_amount.rb', line 18 def tax_rate_percentage @tax_rate_percentage end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/api_reference/models/tax_amount.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_rate_description = hash.key?('tax_rate_description') ? hash['tax_rate_description'] : nil tax_rate_percentage = hash.key?('tax_rate_percentage') ? hash['tax_rate_percentage'] : nil amount = hash.key?('amount') ? hash['amount'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TaxAmount.new(tax_rate_description: tax_rate_description, tax_rate_percentage: tax_rate_percentage, amount: amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/api_reference/models/tax_amount.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['tax_rate_description'] = 'tax_rate_description' @_hash['tax_rate_percentage'] = 'tax_rate_percentage' @_hash['amount'] = 'amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 42 43 |
# File 'lib/api_reference/models/tax_amount.rb', line 39 def self.nullables %w[ tax_rate_percentage ] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/api_reference/models/tax_amount.rb', line 34 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/api_reference/models/tax_amount.rb', line 83 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.tax_rate_description, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.tax_rate_percentage, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.amount, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['tax_rate_description'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['tax_rate_percentage'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['amount'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
116 117 118 119 120 121 |
# File 'lib/api_reference/models/tax_amount.rb', line 116 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_rate_description: #{@tax_rate_description.inspect},"\ " tax_rate_percentage: #{@tax_rate_percentage.inspect}, amount: #{@amount.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 113 |
# File 'lib/api_reference/models/tax_amount.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_rate_description: #{@tax_rate_description}, tax_rate_percentage:"\ " #{@tax_rate_percentage}, amount: #{@amount}, additional_properties:"\ " #{@additional_properties}>" end |