Class: ApiReference::Threshold
- Defined in:
- lib/api_reference/models/threshold.rb
Overview
Thresholds are used to define the conditions under which an alert will be triggered.
Instance Attribute Summary collapse
-
#value ⇒ Float
The value at which an alert will fire.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(value:, additional_properties: nil) ⇒ Threshold
constructor
A new instance of Threshold.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(value:, additional_properties: nil) ⇒ Threshold
Returns a new instance of Threshold.
36 37 38 39 40 41 42 |
# File 'lib/api_reference/models/threshold.rb', line 36 def initialize(value:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @value = value @additional_properties = additional_properties end |
Instance Attribute Details
#value ⇒ Float
The value at which an alert will fire. For credit balance alerts, the alert will fire at or below this value. For usage and cost alerts, the alert will fire at or above this value.
17 18 19 |
# File 'lib/api_reference/models/threshold.rb', line 17 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/api_reference/models/threshold.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. value = hash.key?('value') ? hash['value'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Threshold.new(value: value, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
20 21 22 23 24 |
# File 'lib/api_reference/models/threshold.rb', line 20 def self.names @_hash = {} if @_hash.nil? @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/api_reference/models/threshold.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
27 28 29 |
# File 'lib/api_reference/models/threshold.rb', line 27 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/api_reference/models/threshold.rb', line 65 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.value, ->(val) { val.instance_of? Float }) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['value'], ->(val) { val.instance_of? Float }) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/api_reference/models/threshold.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} value: #{@value.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 |
# File 'lib/api_reference/models/threshold.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} value: #{@value}, additional_properties: #{@additional_properties}>" end |