Class: ApiReference::UsageDiscountCreationParams
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApiReference::UsageDiscountCreationParams
- Defined in:
- lib/api_reference/models/usage_discount_creation_params.rb
Overview
UsageDiscountCreationParams Model.
Instance Attribute Summary collapse
-
#discount_type ⇒ String
readonly
TODO: Write general description for this method.
-
#usage_discount ⇒ Float
Only available if discount_type is
usage.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(usage_discount:, additional_properties: nil) ⇒ UsageDiscountCreationParams
constructor
A new instance of UsageDiscountCreationParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(usage_discount:, additional_properties: nil) ⇒ UsageDiscountCreationParams
Returns a new instance of UsageDiscountCreationParams.
39 40 41 42 43 44 45 46 |
# File 'lib/api_reference/models/usage_discount_creation_params.rb', line 39 def initialize(usage_discount:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @discount_type = 'usage' @usage_discount = usage_discount @additional_properties = additional_properties end |
Instance Attribute Details
#discount_type ⇒ String (readonly)
TODO: Write general description for this method
14 15 16 |
# File 'lib/api_reference/models/usage_discount_creation_params.rb', line 14 def discount_type @discount_type end |
#usage_discount ⇒ Float
Only available if discount_type is usage. Number of usage units that
this discount is for.
19 20 21 |
# File 'lib/api_reference/models/usage_discount_creation_params.rb', line 19 def usage_discount @usage_discount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/api_reference/models/usage_discount_creation_params.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. usage_discount = hash.key?('usage_discount') ? hash['usage_discount'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UsageDiscountCreationParams.new(usage_discount: usage_discount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/api_reference/models/usage_discount_creation_params.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['discount_type'] = 'discount_type' @_hash['usage_discount'] = 'usage_discount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/api_reference/models/usage_discount_creation_params.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/api_reference/models/usage_discount_creation_params.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/api_reference/models/usage_discount_creation_params.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} discount_type: #{@discount_type.inspect}, usage_discount:"\ " #{@usage_discount.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/api_reference/models/usage_discount_creation_params.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} discount_type: #{@discount_type}, usage_discount: #{@usage_discount},"\ " additional_properties: #{@additional_properties}>" end |